declare namespace _default {
    /**
     * Performs accessbility audit of the current application according to the given type or multiple types.
     *
     * @since Xcode 15/iOS 17
     * @param {string[]?} auditTypes - One or more type names to perform the audit for.
     * The full list of available names could be found at
     * https://developer.apple.com/documentation/xctest/xcuiaccessibilityaudittype?language=objc
     * If no type if provided explicitly then XCUIAccessibilityAuditTypeAll is assumed.
     *
     * @returns {Promise<AccessibilityAuditItem[]>} List of found issues or an empty list
     *
     * @this {XCUITestDriver}
     */
    function mobilePerformAccessibilityAudit(this: import("../driver").XCUITestDriver, auditTypes: string[] | null): Promise<AccessibilityAuditItem[]>;
}
export default _default;
export type AccessibilityAuditItem = {
    /**
     * The detailed description of the found accessbility issue.
     */
    detailedDescription: string;
    /**
     * The compact description of the found accessbility issue.
     */
    compactDescription: string;
    /**
     * The name of the audit type this issue belongs to. Could be
     * a number if the type name is unknown.
     */
    auditType: string | number;
    /**
     * The description of the element this issue was found for.
     */
    element: string;
};
export type XCUITestDriver = import('../driver').XCUITestDriver;
//# sourceMappingURL=audit.d.ts.map