declare namespace _default {
    /**
     * @this {XCUITestDriver}
     */
    function getCurrentContext(this: import("../driver").XCUITestDriver): Promise<string>;
    /**
     * Set context
     *
     * @param {string|Context} name - The name of context to set. It could be 'null' as NATIVE_WIN.
     * @param {any} [callback] The callback. (It is not called in this method)
     * @param {boolean} skipReadyCheck - Whether it waits for the new context is ready
     * @this {XCUITestDriver}
     */
    function setContext(this: import("../driver").XCUITestDriver, name: string | import("./types").Context, callback?: any, skipReadyCheck?: boolean): Promise<void>;
    /**
     * @this {XCUITestDriver}
     * @returns {Promise<string[]|FullContext[]>}
     */
    function getContexts(this: import("../driver").XCUITestDriver): Promise<string[] | FullContext[]>;
    /**
     * @this {XCUITestDriver}
     */
    function setWindow(this: import("../driver").XCUITestDriver, name: any, skipReadyCheck: any): Promise<void>;
    /**
     * @this {XCUITestDriver}
     */
    function getWindowHandle(this: import("../driver").XCUITestDriver): Promise<string>;
    /**
     * @this {XCUITestDriver}
     */
    function getWindowHandles(this: import("../driver").XCUITestDriver): Promise<string[]>;
    /**
     * @this {XCUITestDriver}
     */
    function getContextsAndViews(this: import("../driver").XCUITestDriver, useUrl?: boolean): Promise<[import("./types").ViewContext<"NATIVE_APP">]>;
    /**
     * Right now we don't necessarily wait for webview
     * and frame to load, which leads to race conditions and flakiness,
     * let's see if we can transition to something better
     * @this {XCUITestDriver}
     */
    function useNewSafari(this: import("../driver").XCUITestDriver): boolean;
    /**
     * @this {XCUITestDriver}
     */
    function activateRecentWebview(this: import("../driver").XCUITestDriver): Promise<void>;
    /**
     * @this {XCUITestDriver}
     */
    function listWebFrames(this: import("../driver").XCUITestDriver, useUrl?: boolean): Promise<any>;
    /**
     * @this {XCUITestDriver}
     */
    function connectToRemoteDebugger(this: import("../driver").XCUITestDriver): Promise<void>;
    /**
     * Retrieves the list of available contexts.
     *
     * The list includes extended context information, like URLs and page names.
     * This is different from the standard `getContexts` API, because the latter
     * only has web view names without any additional information.
     *
     * @remarks In situations where multiple web views are available at once, the
     * client code would have to connect to each of them in order to detect the
     * one which needs to be interacted with. This extra effort is not needed with
     * the information provided by this extension.
     * @param {number} waitForWebviewMs - The period to poll for available webview(s) (in ms)
     * @returns {Promise<Context[]>} The list of available context objects along with their properties.
     * @this {XCUITestDriver}
     */
    function mobileGetContexts(this: import("../driver").XCUITestDriver, waitForWebviewMs?: number): Promise<import("./types").Context[]>;
    /**
     * @param {import('./types').PageChangeNotification} pageChangeNotification
     * @this {XCUITestDriver}
     */
    function onPageChange(this: import("../driver").XCUITestDriver, pageChangeNotification: import("./types").PageChangeNotification): Promise<void>;
    /**
     * @this {XCUITestDriver}
     */
    function stopRemote(this: import("../driver").XCUITestDriver, closeWindowBeforeDisconnecting?: boolean): Promise<void>;
    /**
     * @this {XCUITestDriver}
     */
    function setCurrentUrl(this: import("../driver").XCUITestDriver, url: any): void;
    /**
     * @this {XCUITestDriver}
     */
    function getCurrentUrl(this: import("../driver").XCUITestDriver): any;
    /**
     * @param {RegExp} titleRegExp
     * @param {RegExp} urlRegExp
     * @this {XCUITestDriver}
     */
    function getRecentWebviewContextId(this: import("../driver").XCUITestDriver, titleRegExp: RegExp, urlRegExp: RegExp): Promise<string | undefined>;
    /**
     * @this {XCUITestDriver}
     */
    function isWebContext(this: import("../driver").XCUITestDriver): boolean;
    /**
     * @this {XCUITestDriver}
     */
    function isWebview(this: import("../driver").XCUITestDriver): boolean;
    /**
     * @this {XCUITestDriver}
     */
    function getNewRemoteDebugger(this: import("../driver").XCUITestDriver): Promise<any>;
}
export default _default;
export type XCUITestDriver = import('../driver').XCUITestDriver;
export type Context = import('./types').Context;
export type FullContext = import('./types').FullContext;
//# sourceMappingURL=context.d.ts.map