declare namespace _default {
    /**
     * Emulates triggering of the given low-level IO HID device event.
     *
     * Popular constants:
     * - `kHIDPage_Consumer` = `0x0C`
     * - `kHIDUsage_Csmr_VolumeIncrement` = `0xE9` (Volume Up)
     * - `kHIDUsage_Csmr_VolumeDecrement` = `0xEA` (Volume Down)
     * - `kHIDUsage_Csmr_Menu` = `0x40` (Home)
     * - `kHIDUsage_Csmr_Power` = `0x30` (Power)
     * - `kHIDUsage_Csmr_Snapshot` = `0x65` (Power + Home)
     *
     * @param {HIDPageEvent} page - The event page identifier
     * @param {HIDUsageEvent} usage - The event usage identifier (usages are defined per-page)
     * @param {number|string} durationSeconds - The event duration in float seconds (XCTest uses `0.005` for a single press event)
     * @this {import('../driver').XCUITestDriver}
     */
    function mobilePerformIoHidEvent(this: import("../driver").XCUITestDriver, page: HIDPageEvent, usage: {
        [x: number]: string;
        kHIDUsage_Sprt_BaseballBat: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_BaseballBat;
        kHIDUsage_Sprt_GolfClub: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_GolfClub;
        kHIDUsage_Sprt_RowingMachine: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_RowingMachine;
        kHIDUsage_Sprt_Treadmill: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_Treadmill;
        kHIDUsage_Sprt_Oar: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_Oar;
        kHIDUsage_Sprt_Slope: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_Slope;
        kHIDUsage_Sprt_Rate: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_Rate;
        kHIDUsage_Sprt_StickSpeed: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_StickSpeed;
        kHIDUsage_Sprt_StickFaceAngle: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_StickFaceAngle;
        kHIDUsage_Sprt_StickHeelOrToe: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_StickHeelOrToe;
        kHIDUsage_Sprt_StickFollowThrough: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_StickFollowThrough;
        kHIDUsage_Sprt_StickTempo: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_StickTempo;
        kHIDUsage_Sprt_StickType: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_StickType;
        kHIDUsage_Sprt_StickHeight: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_StickHeight;
        kHIDUsage_Sprt_Putter: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_Putter;
        kHIDUsage_Sprt_1Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_1Iron;
        kHIDUsage_Sprt_2Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_2Iron;
        kHIDUsage_Sprt_3Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_3Iron;
        kHIDUsage_Sprt_4Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_4Iron;
        kHIDUsage_Sprt_5Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_5Iron;
        kHIDUsage_Sprt_6Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_6Iron;
        kHIDUsage_Sprt_7Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_7Iron;
        kHIDUsage_Sprt_8Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_8Iron;
        kHIDUsage_Sprt_9Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_9Iron;
        kHIDUsage_Sprt_10Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_10Iron;
        kHIDUsage_Sprt_11Iron: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_11Iron;
        kHIDUsage_Sprt_SandWedge: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_SandWedge;
        kHIDUsage_Sprt_LoftWedge: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_LoftWedge;
        kHIDUsage_Sprt_PowerWedge: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_PowerWedge;
        kHIDUsage_Sprt_1Wood: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_1Wood;
        kHIDUsage_Sprt_3Wood: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_3Wood;
        kHIDUsage_Sprt_5Wood: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_5Wood;
        kHIDUsage_Sprt_7Wood: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_7Wood;
        kHIDUsage_Sprt_9Wood: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_9Wood;
        kHIDUsage_Sprt_Reserved: import("./hid-event").HIDUsageSportEvent.kHIDUsage_Sprt_Reserved;
        kHIDUsage_VR_Belt: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_Belt;
        kHIDUsage_VR_BodySuit: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_BodySuit;
        kHIDUsage_VR_Flexor: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_Flexor;
        kHIDUsage_VR_Glove: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_Glove;
        kHIDUsage_VR_HeadTracker: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_HeadTracker;
        kHIDUsage_VR_HeadMountedDisplay: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_HeadMountedDisplay;
        kHIDUsage_VR_HandTracker: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_HandTracker;
        kHIDUsage_VR_Oculometer: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_Oculometer;
        kHIDUsage_VR_Vest: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_Vest;
        kHIDUsage_VR_AnimatronicDevice: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_AnimatronicDevice;
        kHIDUsage_VR_StereoEnable: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_StereoEnable;
        kHIDUsage_VR_DisplayEnable: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_DisplayEnable;
        kHIDUsage_VR_Reserved: import("./hid-event").HIDUsageVREvent.kHIDUsage_VR_Reserved;
        kHIDUsage_Sim_FlightSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_FlightSimulationDevice;
        kHIDUsage_Sim_AutomobileSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_AutomobileSimulationDevice;
        kHIDUsage_Sim_TankSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_TankSimulationDevice;
        kHIDUsage_Sim_SpaceshipSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_SpaceshipSimulationDevice;
        kHIDUsage_Sim_SubmarineSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_SubmarineSimulationDevice;
        kHIDUsage_Sim_SailingSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_SailingSimulationDevice;
        kHIDUsage_Sim_MotorcycleSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_MotorcycleSimulationDevice;
        kHIDUsage_Sim_SportsSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_SportsSimulationDevice;
        kHIDUsage_Sim_AirplaneSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_AirplaneSimulationDevice;
        kHIDUsage_Sim_HelicopterSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_HelicopterSimulationDevice;
        kHIDUsage_Sim_MagicCarpetSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_MagicCarpetSimulationDevice;
        kHIDUsage_Sim_BicycleSimulationDevice: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_BicycleSimulationDevice;
        kHIDUsage_Sim_FlightControlStick: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_FlightControlStick;
        kHIDUsage_Sim_FlightStick: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_FlightStick;
        kHIDUsage_Sim_CyclicControl: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_CyclicControl;
        kHIDUsage_Sim_CyclicTrim: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_CyclicTrim;
        kHIDUsage_Sim_FlightYoke: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_FlightYoke;
        kHIDUsage_Sim_TrackControl: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_TrackControl;
        kHIDUsage_Sim_Aileron: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Aileron;
        kHIDUsage_Sim_AileronTrim: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_AileronTrim;
        kHIDUsage_Sim_AntiTorqueControl: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_AntiTorqueControl;
        kHIDUsage_Sim_AutopilotEnable: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_AutopilotEnable;
        kHIDUsage_Sim_ChaffRelease: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_ChaffRelease;
        kHIDUsage_Sim_CollectiveControl: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_CollectiveControl;
        kHIDUsage_Sim_DiveBrake: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_DiveBrake;
        kHIDUsage_Sim_ElectronicCountermeasures: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_ElectronicCountermeasures;
        kHIDUsage_Sim_Elevator: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Elevator;
        kHIDUsage_Sim_ElevatorTrim: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_ElevatorTrim;
        kHIDUsage_Sim_Rudder: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Rudder;
        kHIDUsage_Sim_Throttle: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Throttle;
        kHIDUsage_Sim_FlightCommunications: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_FlightCommunications;
        kHIDUsage_Sim_FlareRelease: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_FlareRelease;
        kHIDUsage_Sim_LandingGear: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_LandingGear;
        kHIDUsage_Sim_ToeBrake: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_ToeBrake;
        kHIDUsage_Sim_Trigger: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Trigger;
        kHIDUsage_Sim_WeaponsArm: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_WeaponsArm;
        kHIDUsage_Sim_Weapons: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Weapons;
        kHIDUsage_Sim_WingFlaps: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_WingFlaps;
        kHIDUsage_Sim_Accelerator: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Accelerator;
        kHIDUsage_Sim_Brake: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Brake;
        kHIDUsage_Sim_Clutch: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Clutch;
        kHIDUsage_Sim_Shifter: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Shifter;
        kHIDUsage_Sim_Steering: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Steering;
        kHIDUsage_Sim_TurretDirection: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_TurretDirection;
        kHIDUsage_Sim_BarrelElevation: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_BarrelElevation;
        kHIDUsage_Sim_DivePlane: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_DivePlane;
        kHIDUsage_Sim_Ballast: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Ballast;
        kHIDUsage_Sim_BicycleCrank: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_BicycleCrank;
        kHIDUsage_Sim_HandleBars: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_HandleBars;
        kHIDUsage_Sim_FrontBrake: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_FrontBrake;
        kHIDUsage_Sim_RearBrake: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_RearBrake;
        kHIDUsage_Sim_Reserved: import("./hid-event").HIDUsageSimulationEvent.kHIDUsage_Sim_Reserved;
        kHIDUsage_BCS_Undefined: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Undefined;
        kHIDUsage_BCS_BadgeReader: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BadgeReader;
        kHIDUsage_BCS_BarCodeScanner: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BarCodeScanner;
        kHIDUsage_BCS_DumbBarCodeScanner: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DumbBarCodeScanner;
        kHIDUsage_BCS_CordlessScannerBase: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CordlessScannerBase;
        kHIDUsage_BCS_BarCodeScannerCradle: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BarCodeScannerCradle;
        kHIDUsage_BCS_AttributeReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_AttributeReport;
        kHIDUsage_BCS_SettingsReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SettingsReport;
        kHIDUsage_BCS_ScannedDataReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ScannedDataReport;
        kHIDUsage_BCS_RawScannedDataReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_RawScannedDataReport;
        kHIDUsage_BCS_TriggerReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TriggerReport;
        kHIDUsage_BCS_StatusReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_StatusReport;
        kHIDUsage_BCS_UPC_EANControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_EANControlReport;
        kHIDUsage_BCS_EAN2_3LabelControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN2_3LabelControlReport;
        kHIDUsage_BCS_Code39ControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Code39ControlReport;
        kHIDUsage_BCS_Interleaved2of5ControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Interleaved2of5ControlReport;
        kHIDUsage_BCS_Standard2of5ControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Standard2of5ControlReport;
        kHIDUsage_BCS_MSIPlesseyControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MSIPlesseyControlReport;
        kHIDUsage_BCS_CodabarControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CodabarControlReport;
        kHIDUsage_BCS_Code128ControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Code128ControlReport;
        kHIDUsage_BCS_Misc1DControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Misc1DControlReport;
        kHIDUsage_BCS_2DControlReport: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_2DControlReport;
        kHIDUsage_BCS_Aiming_PointerMide: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Aiming_PointerMide;
        kHIDUsage_BCS_BarCodePresentSensor: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BarCodePresentSensor;
        kHIDUsage_BCS_Class1ALaser: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Class1ALaser;
        kHIDUsage_BCS_Class2Laser: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Class2Laser;
        kHIDUsage_BCS_HeaterPresent: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_HeaterPresent;
        kHIDUsage_BCS_ContactScanner: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ContactScanner;
        kHIDUsage_BCS_ElectronicArticleSurveillanceNotification: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ElectronicArticleSurveillanceNotification;
        kHIDUsage_BCS_ConstantElectronicArticleSurveillance: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ConstantElectronicArticleSurveillance;
        kHIDUsage_BCS_ErrorIndication: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ErrorIndication;
        kHIDUsage_BCS_FixedBeeper: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_FixedBeeper;
        kHIDUsage_BCS_GoodDecodeIndication: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GoodDecodeIndication;
        kHIDUsage_BCS_HandsFreeScanning: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_HandsFreeScanning;
        kHIDUsage_BCS_IntrinsicallySafe: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_IntrinsicallySafe;
        kHIDUsage_BCS_KlasseEinsLaser: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_KlasseEinsLaser;
        kHIDUsage_BCS_LongRangeScanner: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_LongRangeScanner;
        kHIDUsage_BCS_MirrorSpeedControl: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MirrorSpeedControl;
        kHIDUsage_BCS_NotOnFileIndication: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_NotOnFileIndication;
        kHIDUsage_BCS_ProgrammableBeeper: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ProgrammableBeeper;
        kHIDUsage_BCS_Triggerless: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Triggerless;
        kHIDUsage_BCS_Wand: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Wand;
        kHIDUsage_BCS_WaterResistant: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_WaterResistant;
        kHIDUsage_BCS_MultiRangeScanner: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MultiRangeScanner;
        kHIDUsage_BCS_ProximitySensor: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ProximitySensor;
        kHIDUsage_BCS_FragmentDecoding: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_FragmentDecoding;
        kHIDUsage_BCS_ScannerReadConfidence: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ScannerReadConfidence;
        kHIDUsage_BCS_DataPrefix: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DataPrefix;
        kHIDUsage_BCS_PrefixAIMI: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PrefixAIMI;
        kHIDUsage_BCS_PrefixNone: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PrefixNone;
        kHIDUsage_BCS_PrefixProprietary: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PrefixProprietary;
        kHIDUsage_BCS_ActiveTime: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ActiveTime;
        kHIDUsage_BCS_AimingLaserPattern: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_AimingLaserPattern;
        kHIDUsage_BCS_BarCodePresent: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BarCodePresent;
        kHIDUsage_BCS_BeeperState: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BeeperState;
        kHIDUsage_BCS_LaserOnTime: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_LaserOnTime;
        kHIDUsage_BCS_LaserState: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_LaserState;
        kHIDUsage_BCS_LockoutTime: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_LockoutTime;
        kHIDUsage_BCS_MotorState: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MotorState;
        kHIDUsage_BCS_MotorTimeout: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MotorTimeout;
        kHIDUsage_BCS_PowerOnResetScanner: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PowerOnResetScanner;
        kHIDUsage_BCS_PreventReadOfBarcodes: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PreventReadOfBarcodes;
        kHIDUsage_BCS_InitiateBarcodeRead: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_InitiateBarcodeRead;
        kHIDUsage_BCS_TriggerState: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TriggerState;
        kHIDUsage_BCS_TriggerMode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TriggerMode;
        kHIDUsage_BCS_TriggerModeBlinkingLaserOn: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TriggerModeBlinkingLaserOn;
        kHIDUsage_BCS_TriggerModeContinuousLaserOn: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TriggerModeContinuousLaserOn;
        kHIDUsage_BCS_TriggerModeLaserOnWhilePulled: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TriggerModeLaserOnWhilePulled;
        kHIDUsage_BCS_TriggerModeLaserStaysOnAfterTriggerRelease: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TriggerModeLaserStaysOnAfterTriggerRelease;
        kHIDUsage_BCS_CommitParametersToNVM: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CommitParametersToNVM;
        kHIDUsage_BCS_ParameterScanning: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ParameterScanning;
        kHIDUsage_BCS_ParametersChanged: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ParametersChanged;
        kHIDUsage_BCS_SetParameterDefaultValues: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SetParameterDefaultValues;
        kHIDUsage_BCS_ScannerInCradle: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ScannerInCradle;
        kHIDUsage_BCS_ScannerInRange: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ScannerInRange;
        kHIDUsage_BCS_AimDuration: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_AimDuration;
        kHIDUsage_BCS_GoodReadLampDuration: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GoodReadLampDuration;
        kHIDUsage_BCS_GoodReadLampIntensity: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GoodReadLampIntensity;
        kHIDUsage_BCS_GoodReadLED: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GoodReadLED;
        kHIDUsage_BCS_GoodReadToneFrequency: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GoodReadToneFrequency;
        kHIDUsage_BCS_GoodReadToneLength: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GoodReadToneLength;
        kHIDUsage_BCS_GoodReadToneVolume: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GoodReadToneVolume;
        kHIDUsage_BCS_NoReadMessage: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_NoReadMessage;
        kHIDUsage_BCS_NotOnFileVolume: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_NotOnFileVolume;
        kHIDUsage_BCS_PowerupBeep: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PowerupBeep;
        kHIDUsage_BCS_SoundErrorBeep: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SoundErrorBeep;
        kHIDUsage_BCS_SoundGoodReadBeep: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SoundGoodReadBeep;
        kHIDUsage_BCS_SoundNotOnFileBeep: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SoundNotOnFileBeep;
        kHIDUsage_BCS_GoodReadWhenToWrite: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GoodReadWhenToWrite;
        kHIDUsage_BCS_GRWTIAfterDecode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GRWTIAfterDecode;
        kHIDUsage_BCS_GRWTIBeep_LampAfterTransmit: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GRWTIBeep_LampAfterTransmit;
        kHIDUsage_BCS_GRWTINoBeep_LampUseAtAll: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_GRWTINoBeep_LampUseAtAll;
        kHIDUsage_BCS_BooklandEAN: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BooklandEAN;
        kHIDUsage_BCS_ConvertEAN8To13Type: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ConvertEAN8To13Type;
        kHIDUsage_BCS_ConvertUPCAToEAN_13: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ConvertUPCAToEAN_13;
        kHIDUsage_BCS_ConvertUPC_EToA: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ConvertUPC_EToA;
        kHIDUsage_BCS_EAN_13: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN_13;
        kHIDUsage_BCS_EAN_8: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN_8;
        kHIDUsage_BCS_EAN_99_128_Mandatory: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN_99_128_Mandatory;
        kHIDUsage_BCS_EAN_99_P5_128_Optional: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN_99_P5_128_Optional;
        kHIDUsage_BCS_UPC_EAN: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_EAN;
        kHIDUsage_BCS_UPC_EANCouponCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_EANCouponCode;
        kHIDUsage_BCS_UPC_EANPeriodicals: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_EANPeriodicals;
        kHIDUsage_BCS_UPC_A: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_A;
        kHIDUsage_BCS_UPC_AWith128Mandatory: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_AWith128Mandatory;
        kHIDUsage_BCS_UPC_AWith128Optical: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_AWith128Optical;
        kHIDUsage_BCS_UPC_AWithP5Optional: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_AWithP5Optional;
        kHIDUsage_BCS_UPC_E: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_E;
        kHIDUsage_BCS_UPC_E1: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UPC_E1;
        kHIDUsage_BCS_Periodical: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Periodical;
        kHIDUsage_BCS_PeriodicalAutoDiscriminatePlus2: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PeriodicalAutoDiscriminatePlus2;
        kHIDUsage_BCS_PeriodicalOnlyDecodeWithPlus2: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PeriodicalOnlyDecodeWithPlus2;
        kHIDUsage_BCS_PeriodicalIgnorePlus2: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PeriodicalIgnorePlus2;
        kHIDUsage_BCS_PeriodicalAutoDiscriminatePlus5: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PeriodicalAutoDiscriminatePlus5;
        kHIDUsage_BCS_PeriodicalOnlyDecodeWithPlus5: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PeriodicalOnlyDecodeWithPlus5;
        kHIDUsage_BCS_PeriodicalIgnorePlus5: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PeriodicalIgnorePlus5;
        kHIDUsage_BCS_Check: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Check;
        kHIDUsage_BCS_CheckDisablePrice: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDisablePrice;
        kHIDUsage_BCS_CheckEnable4DigitPrice: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckEnable4DigitPrice;
        kHIDUsage_BCS_CheckEnable5DigitPrice: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckEnable5DigitPrice;
        kHIDUsage_BCS_CheckEnableEuropean4DigitPrice: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckEnableEuropean4DigitPrice;
        kHIDUsage_BCS_CheckEnableEuropean5DigitPrice: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckEnableEuropean5DigitPrice;
        kHIDUsage_BCS_EANTwoLabel: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EANTwoLabel;
        kHIDUsage_BCS_EANThreeLabel: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EANThreeLabel;
        kHIDUsage_BCS_EAN8FlagDigit1: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN8FlagDigit1;
        kHIDUsage_BCS_EAN8FlagDigit2: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN8FlagDigit2;
        kHIDUsage_BCS_EAN8FlagDigit3: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN8FlagDigit3;
        kHIDUsage_BCS_EAN13FlagDigit1: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN13FlagDigit1;
        kHIDUsage_BCS_EAN13FlagDigit2: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN13FlagDigit2;
        kHIDUsage_BCS_EAN13FlagDigit3: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EAN13FlagDigit3;
        kHIDUsage_BCS_AddEAN2_3LabelDefinition: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_AddEAN2_3LabelDefinition;
        kHIDUsage_BCS_ClearAllEAN2_3LabelDefinitions: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ClearAllEAN2_3LabelDefinitions;
        kHIDUsage_BCS_Codabar: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Codabar;
        kHIDUsage_BCS_Code128: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Code128;
        kHIDUsage_BCS_Code39: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Code39;
        kHIDUsage_BCS_Code93: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Code93;
        kHIDUsage_BCS_FullASCIIConversion: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_FullASCIIConversion;
        kHIDUsage_BCS_Interleaved2of5: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Interleaved2of5;
        kHIDUsage_BCS_ItalianPharmacyCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ItalianPharmacyCode;
        kHIDUsage_BCS_MSI_Plessey: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MSI_Plessey;
        kHIDUsage_BCS_Standard2of5IATA: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Standard2of5IATA;
        kHIDUsage_BCS_Standard2of5: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Standard2of5;
        kHIDUsage_BCS_TransmitStart_Stop: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TransmitStart_Stop;
        kHIDUsage_BCS_TriOptic: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TriOptic;
        kHIDUsage_BCS_UCC_EAN_128: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UCC_EAN_128;
        kHIDUsage_BCS_CheckDigit: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigit;
        kHIDUsage_BCS_CheckDigitDisable: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitDisable;
        kHIDUsage_BCS_CheckDigitEnableInterleaved2of5OPCC: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitEnableInterleaved2of5OPCC;
        kHIDUsage_BCS_CheckDigitEnableInterleaved2of5USS: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitEnableInterleaved2of5USS;
        kHIDUsage_BCS_CheckDigitEnableStandard2of5OPCC: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitEnableInterleaved2of5OPCC;
        kHIDUsage_BCS_CheckDigitEnableStandard2of5USS: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitEnableInterleaved2of5USS;
        kHIDUsage_BCS_CheckDigitEnableOneMSIPlessey: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitEnableOneMSIPlessey;
        kHIDUsage_BCS_CheckDigitEnableTwoMSIPlessey: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitEnableTwoMSIPlessey;
        kHIDUsage_BCS_CheckDigitCodabarEnable: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitCodabarEnable;
        kHIDUsage_BCS_CheckDigitCode99Enable: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CheckDigitCode99Enable;
        kHIDUsage_BCS_TransmitCheckDigit: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_TransmitCheckDigit;
        kHIDUsage_BCS_DisableCheckDigitTransmit: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DisableCheckDigitTransmit;
        kHIDUsage_BCS_EnableCheckDigitTransmit: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_EnableCheckDigitTransmit;
        kHIDUsage_BCS_SymbologyIdentifier1: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SymbologyIdentifier1;
        kHIDUsage_BCS_SymbologyIdentifier2: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SymbologyIdentifier2;
        kHIDUsage_BCS_SymbologyIdentifier3: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SymbologyIdentifier3;
        kHIDUsage_BCS_DecodedData: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DecodedData;
        kHIDUsage_BCS_DecodeDataContinued: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DecodeDataContinued;
        kHIDUsage_BCS_BarSpaceData: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BarSpaceData;
        kHIDUsage_BCS_ScannerDataAccuracy: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ScannerDataAccuracy;
        kHIDUsage_BCS_RawDataPolarity: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_RawDataPolarity;
        kHIDUsage_BCS_PolarityInvertedBarCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PolarityInvertedBarCode;
        kHIDUsage_BCS_PolarityNormalBarCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PolarityInvertedBarCode;
        kHIDUsage_BCS_MinimumLengthToDecode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MinimumLengthToDecode;
        kHIDUsage_BCS_MaximumLengthToDecode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MaximumLengthToDecode;
        kHIDUsage_BCS_FirstDiscreteLengthToDecode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_FirstDiscreteLengthToDecode;
        kHIDUsage_BCS_SecondDiscreteLengthToDecode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SecondDiscreteLengthToDecode;
        kHIDUsage_BCS_DataLengthMethod: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DataLengthMethod;
        kHIDUsage_BCS_DLMethodReadAny: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DLMethodReadAny;
        kHIDUsage_BCS_DLMethodCheckInRange: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DLMethodCheckInRange;
        kHIDUsage_BCS_DLMethodCheckForDiscrete: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DLMethodCheckForDiscrete;
        kHIDUsage_BCS_AztecCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_AztecCode;
        kHIDUsage_BCS_BC412: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_BC412;
        kHIDUsage_BCS_ChannelCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_ChannelCode;
        kHIDUsage_BCS_Code16: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Code16;
        kHIDUsage_BCS_Code32: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Code32;
        kHIDUsage_BCS_Code49: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Code49;
        kHIDUsage_BCS_CodeOne: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_CodeOne;
        kHIDUsage_BCS_Colorcode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_Colorcode;
        kHIDUsage_BCS_DataMatrix: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_DataMatrix;
        kHIDUsage_BCS_MaxiCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MaxiCode;
        kHIDUsage_BCS_MicroPDF: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_MicroPDF;
        kHIDUsage_BCS_PDF_417: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PDF_417;
        kHIDUsage_BCS_PosiCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_PosiCode;
        kHIDUsage_BCS_QRCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_QRCode;
        kHIDUsage_BCS_SuperCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_SuperCode;
        kHIDUsage_BCS_UltraCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_UltraCode;
        kHIDUsage_BCS_USB_5_SlugCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_USB_5_SlugCode;
        kHIDUsage_BCS_VeriCode: import("./hid-event").HIDUsageBCSEvent.kHIDUsage_BCS_VeriCode;
        kHIDUsage_WD_Undefined: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_Undefined;
        kHIDUsage_WD_WeighingDevice: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeighingDevice;
        kHIDUsage_WD_ScaleScaleDevice: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleDevice;
        kHIDUsage_WD_ScaleScaleClassIMetricCL: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIMetricCL;
        kHIDUsage_WD_ScaleScaleClassIMetric: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIMetric;
        kHIDUsage_WD_ScaleScaleClassIIMetric: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIIMetric;
        kHIDUsage_WD_ScaleScaleClassIIIMetric: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIIIMetric;
        kHIDUsage_WD_ScaleScaleClassIIILMetric: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIIILMetric;
        kHIDUsage_WD_ScaleScaleClassIVMetric: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIVMetric;
        kHIDUsage_WD_ScaleScaleClassIIIEnglish: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIIIEnglish;
        kHIDUsage_WD_ScaleScaleClassIIILEnglish: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIIILEnglish;
        kHIDUsage_WD_ScaleScaleClassIVEnglish: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassIVEnglish;
        kHIDUsage_WD_ScaleScaleClassGeneric: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleScaleClassGeneric;
        kHIDUsage_WD_ScaleAtrributeReport: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleAtrributeReport;
        kHIDUsage_WD_ScaleControlReport: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleControlReport;
        kHIDUsage_WD_ScaleDataReport: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleDataReport;
        kHIDUsage_WD_ScaleStatusReport: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusReport;
        kHIDUsage_WD_ScaleWeightLimitReport: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleWeightLimitReport;
        kHIDUsage_WD_ScaleStatisticsReport: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatisticsReport;
        kHIDUsage_WD_DataWeight: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_DataWeight;
        kHIDUsage_WD_DataScaling: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_DataScaling;
        kHIDUsage_WD_WeightUnit: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnit;
        kHIDUsage_WD_WeightUnitMilligram: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitMilligram;
        kHIDUsage_WD_WeightUnitGram: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitGram;
        kHIDUsage_WD_WeightUnitKilogram: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitKilogram;
        kHIDUsage_WD_WeightUnitCarats: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitCarats;
        kHIDUsage_WD_WeightUnitTaels: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitTaels;
        kHIDUsage_WD_WeightUnitGrains: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitGrains;
        kHIDUsage_WD_WeightUnitPennyweights: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitPennyweights;
        kHIDUsage_WD_WeightUnitMetricTon: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitMetricTon;
        kHIDUsage_WD_WeightUnitAvoirTon: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitAvoirTon;
        kHIDUsage_WD_WeightUnitTroyOunce: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitTroyOunce;
        kHIDUsage_WD_WeightUnitOunce: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitOunce;
        kHIDUsage_WD_WeightUnitPound: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_WeightUnitPound;
        kHIDUsage_WD_CalibrationCount: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_CalibrationCount;
        kHIDUsage_WD_RezeroCount: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_RezeroCount;
        kHIDUsage_WD_ScaleStatus: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatus;
        kHIDUsage_WD_ScaleStatusFault: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusFault;
        kHIDUsage_WD_ScaleStatusStableAtZero: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusStableAtZero;
        kHIDUsage_WD_ScaleStatusInMotion: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusInMotion;
        kHIDUsage_WD_ScaleStatusWeightStable: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusWeightStable;
        kHIDUsage_WD_ScaleStatusUnderZero: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusUnderZero;
        kHIDUsage_WD_ScaleStatusOverWeightLimit: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusOverWeightLimit;
        kHIDUsage_WD_ScaleStatusRequiresCalibration: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusRequiresCalibration;
        kHIDUsage_WD_ScaleStatusRequiresRezeroing: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ScaleStatusRequiresRezeroing;
        kHIDUsage_WD_ZeroScale: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_ZeroScale;
        kHIDUsage_WD_EnforcedZeroReturn: import("./hid-event").HIDUsageWeighingDeviceEvent.kHIDUsage_WD_EnforcedZeroReturn;
        kHIDUsage_KeyboardErrorRollOver: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardErrorRollOver;
        kHIDUsage_KeyboardPOSTFail: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPOSTFail;
        kHIDUsage_KeyboardErrorUndefined: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardErrorUndefined;
        kHIDUsage_KeyboardA: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardA;
        kHIDUsage_KeyboardB: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardB;
        kHIDUsage_KeyboardC: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardC;
        kHIDUsage_KeyboardD: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardD;
        kHIDUsage_KeyboardE: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardE;
        kHIDUsage_KeyboardF: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF;
        kHIDUsage_KeyboardG: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardG;
        kHIDUsage_KeyboardH: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardH;
        kHIDUsage_KeyboardI: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardI;
        kHIDUsage_KeyboardJ: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardJ;
        kHIDUsage_KeyboardK: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardK;
        kHIDUsage_KeyboardL: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardL;
        kHIDUsage_KeyboardM: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardM;
        kHIDUsage_KeyboardN: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardN;
        kHIDUsage_KeyboardO: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardO;
        kHIDUsage_KeyboardP: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardP;
        kHIDUsage_KeyboardQ: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardQ;
        kHIDUsage_KeyboardR: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardR;
        kHIDUsage_KeyboardS: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardS;
        kHIDUsage_KeyboardT: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardT;
        kHIDUsage_KeyboardU: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardU;
        kHIDUsage_KeyboardV: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardV;
        kHIDUsage_KeyboardW: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardW;
        kHIDUsage_KeyboardX: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardX;
        kHIDUsage_KeyboardY: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardY;
        kHIDUsage_KeyboardZ: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardZ;
        kHIDUsage_Keyboard1: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard1;
        kHIDUsage_Keyboard2: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard2;
        kHIDUsage_Keyboard3: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard3;
        kHIDUsage_Keyboard4: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard4;
        kHIDUsage_Keyboard5: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard5;
        kHIDUsage_Keyboard6: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard6;
        kHIDUsage_Keyboard7: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard7;
        kHIDUsage_Keyboard8: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard8;
        kHIDUsage_Keyboard9: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard9;
        kHIDUsage_Keyboard0: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard0;
        kHIDUsage_KeyboardReturnOrEnter: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardReturnOrEnter;
        kHIDUsage_KeyboardEscape: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardEscape;
        kHIDUsage_KeyboardDeleteOrBackspace: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardDeleteOrBackspace;
        kHIDUsage_KeyboardTab: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardTab;
        kHIDUsage_KeyboardSpacebar: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardSpacebar;
        kHIDUsage_KeyboardHyphen: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardHyphen;
        kHIDUsage_KeyboardEqualSign: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardEqualSign;
        kHIDUsage_KeyboardOpenBracket: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardOpenBracket;
        kHIDUsage_KeyboardCloseBracket: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardCloseBracket;
        kHIDUsage_KeyboardBackslash: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardBackslash;
        kHIDUsage_KeyboardNonUSPound: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardNonUSPound;
        kHIDUsage_KeyboardSemicolon: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardSemicolon;
        kHIDUsage_KeyboardQuote: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardQuote;
        kHIDUsage_KeyboardGraveAccentAndTilde: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardGraveAccentAndTilde;
        kHIDUsage_KeyboardComma: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardComma;
        kHIDUsage_KeyboardPeriod: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPeriod;
        kHIDUsage_KeyboardSlash: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardSlash;
        kHIDUsage_KeyboardCapsLock: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardCapsLock;
        kHIDUsage_KeyboardF1: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF1;
        kHIDUsage_KeyboardF2: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF2;
        kHIDUsage_KeyboardF3: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF3;
        kHIDUsage_KeyboardF4: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF4;
        kHIDUsage_KeyboardF5: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF5;
        kHIDUsage_KeyboardF6: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF6;
        kHIDUsage_KeyboardF7: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF7;
        kHIDUsage_KeyboardF8: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF8;
        kHIDUsage_KeyboardF9: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF9;
        kHIDUsage_KeyboardF10: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF10;
        kHIDUsage_KeyboardF11: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF11;
        kHIDUsage_KeyboardF12: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF12;
        kHIDUsage_KeyboardPrintScreen: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPrintScreen;
        kHIDUsage_KeyboardScrollLock: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardScrollLock;
        kHIDUsage_KeyboardPause: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPause;
        kHIDUsage_KeyboardInsert: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInsert;
        kHIDUsage_KeyboardHome: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardHome;
        kHIDUsage_KeyboardPageUp: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPageUp;
        kHIDUsage_KeyboardDeleteForward: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardDeleteForward;
        kHIDUsage_KeyboardEnd: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardEnd;
        kHIDUsage_KeyboardPageDown: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPageDown;
        kHIDUsage_KeyboardRightArrow: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardRightArrow;
        kHIDUsage_KeyboardLeftArrow: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLeftArrow;
        kHIDUsage_KeyboardDownArrow: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardDownArrow;
        kHIDUsage_KeyboardUpArrow: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardUpArrow;
        kHIDUsage_KeypadNumLock: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadNumLock;
        kHIDUsage_KeypadSlash: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadSlash;
        kHIDUsage_KeypadAsterisk: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadAsterisk;
        kHIDUsage_KeypadHyphen: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadHyphen;
        kHIDUsage_KeypadPlus: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadPlus;
        kHIDUsage_KeypadEnter: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadEnter;
        kHIDUsage_Keypad1: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad1;
        kHIDUsage_Keypad2: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad2;
        kHIDUsage_Keypad3: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad3;
        kHIDUsage_Keypad4: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad4;
        kHIDUsage_Keypad5: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad5;
        kHIDUsage_Keypad6: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad6;
        kHIDUsage_Keypad7: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad7;
        kHIDUsage_Keypad8: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad8;
        kHIDUsage_Keypad9: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad9;
        kHIDUsage_Keypad0: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keypad0;
        kHIDUsage_KeypadPeriod: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadPeriod;
        kHIDUsage_KeyboardNonUSBackslash: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardNonUSBackslash;
        kHIDUsage_KeyboardApplication: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardApplication;
        kHIDUsage_KeyboardPower: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPower;
        kHIDUsage_KeypadEqualSign: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadEqualSign;
        kHIDUsage_KeyboardF13: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF13;
        kHIDUsage_KeyboardF14: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF14;
        kHIDUsage_KeyboardF15: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF15;
        kHIDUsage_KeyboardF16: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF16;
        kHIDUsage_KeyboardF17: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF17;
        kHIDUsage_KeyboardF18: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF18;
        kHIDUsage_KeyboardF19: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF19;
        kHIDUsage_KeyboardF20: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF20;
        kHIDUsage_KeyboardF21: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF21;
        kHIDUsage_KeyboardF22: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF22;
        kHIDUsage_KeyboardF23: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF23;
        kHIDUsage_KeyboardF24: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardF24;
        kHIDUsage_KeyboardExecute: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardExecute;
        kHIDUsage_KeyboardHelp: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardHelp;
        kHIDUsage_KeyboardMenu: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardMenu;
        kHIDUsage_KeyboardSelect: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardSelect;
        kHIDUsage_KeyboardStop: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardStop;
        kHIDUsage_KeyboardAgain: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardAgain;
        kHIDUsage_KeyboardUndo: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardUndo;
        kHIDUsage_KeyboardCut: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardCut;
        kHIDUsage_KeyboardCopy: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardCopy;
        kHIDUsage_KeyboardPaste: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPaste;
        kHIDUsage_KeyboardFind: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardFind;
        kHIDUsage_KeyboardMute: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardMute;
        kHIDUsage_KeyboardVolumeUp: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardVolumeUp;
        kHIDUsage_KeyboardVolumeDown: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardVolumeDown;
        kHIDUsage_KeyboardLockingCapsLock: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLockingCapsLock;
        kHIDUsage_KeyboardLockingNumLock: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLockingNumLock;
        kHIDUsage_KeyboardLockingScrollLock: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLockingScrollLock;
        kHIDUsage_KeypadComma: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadComma;
        kHIDUsage_KeypadEqualSignAS400: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeypadEqualSignAS400;
        kHIDUsage_KeyboardInternational1: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational1;
        kHIDUsage_KeyboardInternational2: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational2;
        kHIDUsage_KeyboardInternational3: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational3;
        kHIDUsage_KeyboardInternational4: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational4;
        kHIDUsage_KeyboardInternational5: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational5;
        kHIDUsage_KeyboardInternational6: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational6;
        kHIDUsage_KeyboardInternational7: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational7;
        kHIDUsage_KeyboardInternational8: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational8;
        kHIDUsage_KeyboardInternational9: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardInternational9;
        kHIDUsage_KeyboardLANG1: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG1;
        kHIDUsage_KeyboardLANG2: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG2;
        kHIDUsage_KeyboardLANG3: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG3;
        kHIDUsage_KeyboardLANG4: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG4;
        kHIDUsage_KeyboardLANG5: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG5;
        kHIDUsage_KeyboardLANG6: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG6;
        kHIDUsage_KeyboardLANG7: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG7;
        kHIDUsage_KeyboardLANG8: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG8;
        kHIDUsage_KeyboardLANG9: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLANG9;
        kHIDUsage_KeyboardAlternateErase: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardAlternateErase;
        kHIDUsage_KeyboardSysReqOrAttention: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardSysReqOrAttention;
        kHIDUsage_KeyboardCancel: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardCancel;
        kHIDUsage_KeyboardClear: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardClear;
        kHIDUsage_KeyboardPrior: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardPrior;
        kHIDUsage_KeyboardReturn: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardReturn;
        kHIDUsage_KeyboardSeparator: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardSeparator;
        kHIDUsage_KeyboardOut: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardOut;
        kHIDUsage_KeyboardOper: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardOper;
        kHIDUsage_KeyboardClearOrAgain: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardClearOrAgain;
        kHIDUsage_KeyboardCrSelOrProps: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardCrSelOrProps;
        kHIDUsage_KeyboardExSel: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardExSel;
        kHIDUsage_KeyboardLeftControl: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLeftControl;
        kHIDUsage_KeyboardLeftShift: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLeftShift;
        kHIDUsage_KeyboardLeftAlt: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLeftAlt;
        kHIDUsage_KeyboardLeftGUI: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardLeftGUI;
        kHIDUsage_KeyboardRightControl: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardRightControl;
        kHIDUsage_KeyboardRightShift: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardRightShift;
        kHIDUsage_KeyboardRightAlt: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardRightAlt;
        kHIDUsage_KeyboardRightGUI: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_KeyboardRightGUI;
        kHIDUsage_Keyboard_Reserved: import("./hid-event").HIDUsageKeyboardEvent.kHIDUsage_Keyboard_Reserved;
        kHIDUsage_GD_Pointer: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Pointer;
        kHIDUsage_GD_Mouse: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Mouse;
        kHIDUsage_GD_Joystick: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Joystick;
        kHIDUsage_GD_GamePad: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_GamePad;
        kHIDUsage_GD_Keyboard: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Keyboard;
        kHIDUsage_GD_Keypad: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Keypad;
        kHIDUsage_GD_MultiAxisController: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_MultiAxisController;
        kHIDUsage_GD_X: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_X;
        kHIDUsage_GD_Y: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Y;
        kHIDUsage_GD_Z: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Z;
        kHIDUsage_GD_Rx: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Rx;
        kHIDUsage_GD_Ry: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Ry;
        kHIDUsage_GD_Rz: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Rz;
        kHIDUsage_GD_Slider: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Slider;
        kHIDUsage_GD_Dial: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Dial;
        kHIDUsage_GD_Wheel: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Wheel;
        kHIDUsage_GD_Hatswitch: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Hatswitch;
        kHIDUsage_GD_CountedBuffer: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_CountedBuffer;
        kHIDUsage_GD_ByteCount: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_ByteCount;
        kHIDUsage_GD_MotionWakeup: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_MotionWakeup;
        kHIDUsage_GD_Start: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Start;
        kHIDUsage_GD_Select: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Select;
        kHIDUsage_GD_Vx: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Vx;
        kHIDUsage_GD_Vy: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Vy;
        kHIDUsage_GD_Vz: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Vz;
        kHIDUsage_GD_Vbrx: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Vbrx;
        kHIDUsage_GD_Vbry: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Vbry;
        kHIDUsage_GD_Vbrz: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Vbrz;
        kHIDUsage_GD_Vno: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Vno;
        kHIDUsage_GD_SystemControl: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemControl;
        kHIDUsage_GD_SystemPowerDown: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemPowerDown;
        kHIDUsage_GD_SystemSleep: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemSleep;
        kHIDUsage_GD_SystemWakeUp: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemWakeUp;
        kHIDUsage_GD_SystemContextMenu: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemContextMenu;
        kHIDUsage_GD_SystemMainMenu: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemMainMenu;
        kHIDUsage_GD_SystemAppMenu: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemAppMenu;
        kHIDUsage_GD_SystemMenuHelp: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemMenuHelp;
        kHIDUsage_GD_SystemMenuExit: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemMenuExit;
        kHIDUsage_GD_SystemMenu: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemMenu;
        kHIDUsage_GD_SystemMenuRight: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemMenuRight;
        kHIDUsage_GD_SystemMenuLeft: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemMenuLeft;
        kHIDUsage_GD_SystemMenuUp: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemMenuUp;
        kHIDUsage_GD_SystemMenuDown: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_SystemMenuDown;
        kHIDUsage_GD_DPadUp: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_DPadUp;
        kHIDUsage_GD_DPadDown: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_DPadDown;
        kHIDUsage_GD_DPadRight: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_DPadRight;
        kHIDUsage_GD_DPadLeft: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_DPadLeft;
        kHIDUsage_GD_Reserved: import("./hid-event").HIDUsageGenericDesktopEvent.kHIDUsage_GD_Reserved;
        kHIDUsage_Button_1: import("./hid-event").HIDUsageButtonEvent.kHIDUsage_Button_1;
        kHIDUsage_Button_2: import("./hid-event").HIDUsageButtonEvent.kHIDUsage_Button_2;
        kHIDUsage_Button_3: import("./hid-event").HIDUsageButtonEvent.kHIDUsage_Button_3;
        kHIDUsage_Button_4: import("./hid-event").HIDUsageButtonEvent.kHIDUsage_Button_4;
        kHIDUsage_Button_65535: import("./hid-event").HIDUsageButtonEvent.kHIDUsage_Button_65535;
        kHIDUsage_LED_NumLock: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_NumLock;
        kHIDUsage_LED_CapsLock: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_CapsLock;
        kHIDUsage_LED_ScrollLock: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_ScrollLock;
        kHIDUsage_LED_Compose: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Compose;
        kHIDUsage_LED_Kana: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Kana;
        kHIDUsage_LED_Power: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Power;
        kHIDUsage_LED_Shift: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Shift;
        kHIDUsage_LED_DoNotDisturb: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_DoNotDisturb;
        kHIDUsage_LED_Mute: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Mute;
        kHIDUsage_LED_ToneEnable: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_ToneEnable;
        kHIDUsage_LED_HighCutFilter: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_HighCutFilter;
        kHIDUsage_LED_LowCutFilter: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_LowCutFilter;
        kHIDUsage_LED_EqualizerEnable: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_EqualizerEnable;
        kHIDUsage_LED_SoundFieldOn: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_SoundFieldOn;
        kHIDUsage_LED_SurroundOn: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_SurroundOn;
        kHIDUsage_LED_Repeat: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Repeat;
        kHIDUsage_LED_Stereo: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Stereo;
        kHIDUsage_LED_SamplingRateDetect: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_SamplingRateDetect;
        kHIDUsage_LED_Spinning: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Spinning;
        kHIDUsage_LED_CAV: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_CAV;
        kHIDUsage_LED_CLV: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_CLV;
        kHIDUsage_LED_RecordingFormatDetect: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_RecordingFormatDetect;
        kHIDUsage_LED_OffHook: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_OffHook;
        kHIDUsage_LED_Ring: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Ring;
        kHIDUsage_LED_MessageWaiting: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_MessageWaiting;
        kHIDUsage_LED_DataMode: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_DataMode;
        kHIDUsage_LED_BatteryOperation: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_BatteryOperation;
        kHIDUsage_LED_BatteryOK: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_BatteryOK;
        kHIDUsage_LED_BatteryLow: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_BatteryLow;
        kHIDUsage_LED_Speaker: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Speaker;
        kHIDUsage_LED_HeadSet: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_HeadSet;
        kHIDUsage_LED_Hold: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Hold;
        kHIDUsage_LED_Microphone: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Microphone;
        kHIDUsage_LED_Coverage: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Coverage;
        kHIDUsage_LED_NightMode: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_NightMode;
        kHIDUsage_LED_SendCalls: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_SendCalls;
        kHIDUsage_LED_CallPickup: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_CallPickup;
        kHIDUsage_LED_Conference: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Conference;
        kHIDUsage_LED_StandBy: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_StandBy;
        kHIDUsage_LED_CameraOn: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_CameraOn;
        kHIDUsage_LED_CameraOff: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_CameraOff;
        kHIDUsage_LED_OnLine: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_OnLine;
        kHIDUsage_LED_OffLine: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_OffLine;
        kHIDUsage_LED_Busy: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Busy;
        kHIDUsage_LED_Ready: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Ready;
        kHIDUsage_LED_PaperOut: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_PaperOut;
        kHIDUsage_LED_PaperJam: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_PaperJam;
        kHIDUsage_LED_Remote: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Remote;
        kHIDUsage_LED_Forward: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Forward;
        kHIDUsage_LED_Reverse: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Reverse;
        kHIDUsage_LED_Stop: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Stop;
        kHIDUsage_LED_Rewind: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Rewind;
        kHIDUsage_LED_FastForward: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_FastForward;
        kHIDUsage_LED_Play: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Play;
        kHIDUsage_LED_Pause: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Pause;
        kHIDUsage_LED_Record: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Record;
        kHIDUsage_LED_Error: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Error;
        kHIDUsage_LED_Usage: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Usage;
        kHIDUsage_LED_UsageInUseIndicator: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_UsageInUseIndicator;
        kHIDUsage_LED_UsageMultiModeIndicator: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_UsageMultiModeIndicator;
        kHIDUsage_LED_IndicatorOn: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_IndicatorOn;
        kHIDUsage_LED_IndicatorFlash: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_IndicatorFlash;
        kHIDUsage_LED_IndicatorSlowBlink: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_IndicatorSlowBlink;
        kHIDUsage_LED_IndicatorFastBlink: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_IndicatorFastBlink;
        kHIDUsage_LED_IndicatorOff: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_IndicatorOff;
        kHIDUsage_LED_FlashOnTime: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_FlashOnTime;
        kHIDUsage_LED_SlowBlinkOnTime: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_SlowBlinkOnTime;
        kHIDUsage_LED_SlowBlinkOffTime: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_SlowBlinkOffTime;
        kHIDUsage_LED_FastBlinkOnTime: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_FastBlinkOnTime;
        kHIDUsage_LED_FastBlinkOffTime: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_FastBlinkOffTime;
        kHIDUsage_LED_UsageIndicatorColor: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_UsageIndicatorColor;
        kHIDUsage_LED_IndicatorRed: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_IndicatorRed;
        kHIDUsage_LED_IndicatorGreen: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_IndicatorGreen;
        kHIDUsage_LED_IndicatorAmber: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_IndicatorAmber;
        kHIDUsage_LED_GenericIndicator: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_GenericIndicator;
        kHIDUsage_LED_SystemSuspend: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_SystemSuspend;
        kHIDUsage_LED_ExternalPowerConnected: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_ExternalPowerConnected;
        kHIDUsage_LED_Reserved: import("./hid-event").HIDUsageLEDEvent.kHIDUsage_LED_Reserved;
        kHIDUsage_Dig_Digitizer: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Digitizer;
        kHIDUsage_Dig_Pen: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Pen;
        kHIDUsage_Dig_LightPen: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_LightPen;
        kHIDUsage_Dig_TouchScreen: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_TouchScreen;
        kHIDUsage_Dig_TouchPad: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_TouchPad;
        kHIDUsage_Dig_WhiteBoard: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_WhiteBoard;
        kHIDUsage_Dig_CoordinateMeasuringMachine: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_CoordinateMeasuringMachine;
        kHIDUsage_Dig_3DDigitizer: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_3DDigitizer;
        kHIDUsage_Dig_StereoPlotter: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_StereoPlotter;
        kHIDUsage_Dig_ArticulatedArm: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_ArticulatedArm;
        kHIDUsage_Dig_Armature: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Armature;
        kHIDUsage_Dig_MultiplePointDigitizer: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_MultiplePointDigitizer;
        kHIDUsage_Dig_FreeSpaceWand: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_FreeSpaceWand;
        kHIDUsage_Dig_Stylus: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Stylus;
        kHIDUsage_Dig_Puck: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Puck;
        kHIDUsage_Dig_Finger: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Finger;
        kHIDUsage_Dig_TipPressure: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_TipPressure;
        kHIDUsage_Dig_BarrelPressure: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_BarrelPressure;
        kHIDUsage_Dig_InRange: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_InRange;
        kHIDUsage_Dig_Touch: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Touch;
        kHIDUsage_Dig_Untouch: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Untouch;
        kHIDUsage_Dig_Tap: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Tap;
        kHIDUsage_Dig_Quality: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Quality;
        kHIDUsage_Dig_DataValid: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_DataValid;
        kHIDUsage_Dig_TransducerIndex: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_TransducerIndex;
        kHIDUsage_Dig_TabletFunctionKeys: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_TabletFunctionKeys;
        kHIDUsage_Dig_ProgramChangeKeys: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_ProgramChangeKeys;
        kHIDUsage_Dig_BatteryStrength: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_BatteryStrength;
        kHIDUsage_Dig_Invert: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Invert;
        kHIDUsage_Dig_XTilt: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_XTilt;
        kHIDUsage_Dig_YTilt: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_YTilt;
        kHIDUsage_Dig_Azimuth: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Azimuth;
        kHIDUsage_Dig_Altitude: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Altitude;
        kHIDUsage_Dig_Twist: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Twist;
        kHIDUsage_Dig_TipSwitch: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_TipSwitch;
        kHIDUsage_Dig_SecondaryTipSwitch: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_SecondaryTipSwitch;
        kHIDUsage_Dig_BarrelSwitch: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_BarrelSwitch;
        kHIDUsage_Dig_Eraser: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Eraser;
        kHIDUsage_Dig_TabletPick: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_TabletPick;
        kHIDUsage_Dig_Reserved: import("./hid-event").HIDUsageDigitizerEvent.kHIDUsage_Dig_Reserved;
        kHIDUsage_Csmr_ConsumerControl: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ConsumerControl;
        kHIDUsage_Csmr_NumericKeyPad: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_NumericKeyPad;
        kHIDUsage_Csmr_ProgrammableButtons: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ProgrammableButtons;
        kHIDUsage_Csmr_Plus10: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Plus10;
        kHIDUsage_Csmr_Plus100: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Plus100;
        kHIDUsage_Csmr_AMOrPM: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_AMOrPM;
        kHIDUsage_Csmr_Power: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Power;
        kHIDUsage_Csmr_Reset: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Reset;
        kHIDUsage_Csmr_Sleep: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Sleep;
        kHIDUsage_Csmr_SleepAfter: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SleepAfter;
        kHIDUsage_Csmr_SleepMode: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SleepMode;
        kHIDUsage_Csmr_Illumination: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Illumination;
        kHIDUsage_Csmr_FunctionButtons: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_FunctionButtons;
        kHIDUsage_Csmr_Menu: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Menu;
        kHIDUsage_Csmr_MenuPick: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MenuPick;
        kHIDUsage_Csmr_MenuUp: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MenuUp;
        kHIDUsage_Csmr_MenuDown: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MenuDown;
        kHIDUsage_Csmr_MenuLeft: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MenuLeft;
        kHIDUsage_Csmr_MenuRight: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MenuRight;
        kHIDUsage_Csmr_MenuEscape: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MenuEscape;
        kHIDUsage_Csmr_MenuValueIncrease: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MenuValueIncrease;
        kHIDUsage_Csmr_MenuValueDecrease: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MenuValueDecrease;
        kHIDUsage_Csmr_DataOnScreen: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_DataOnScreen;
        kHIDUsage_Csmr_ClosedCaption: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ClosedCaption;
        kHIDUsage_Csmr_ClosedCaptionSelect: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ClosedCaptionSelect;
        kHIDUsage_Csmr_VCROrTV: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_VCROrTV;
        kHIDUsage_Csmr_BroadcastMode: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_BroadcastMode;
        kHIDUsage_Csmr_Snapshot: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Snapshot;
        kHIDUsage_Csmr_Still: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Still;
        kHIDUsage_Csmr_Selection: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Selection;
        kHIDUsage_Csmr_Assign: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Assign;
        kHIDUsage_Csmr_ModeStep: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ModeStep;
        kHIDUsage_Csmr_RecallLast: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_RecallLast;
        kHIDUsage_Csmr_EnterChannel: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_EnterChannel;
        kHIDUsage_Csmr_OrderMovie: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_OrderMovie;
        kHIDUsage_Csmr_Channel: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Channel;
        kHIDUsage_Csmr_MediaSelection: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelection;
        kHIDUsage_Csmr_MediaSelectComputer: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectComputer;
        kHIDUsage_Csmr_MediaSelectTV: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectTV;
        kHIDUsage_Csmr_MediaSelectWWW: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectWWW;
        kHIDUsage_Csmr_MediaSelectDVD: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectDVD;
        kHIDUsage_Csmr_MediaSelectTelephone: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectTelephone;
        kHIDUsage_Csmr_MediaSelectProgramGuide: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectProgramGuide;
        kHIDUsage_Csmr_MediaSelectVideoPhone: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectVideoPhone;
        kHIDUsage_Csmr_MediaSelectGames: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectGames;
        kHIDUsage_Csmr_MediaSelectMessages: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectMessages;
        kHIDUsage_Csmr_MediaSelectCD: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectCD;
        kHIDUsage_Csmr_MediaSelectVCR: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectVCR;
        kHIDUsage_Csmr_MediaSelectTuner: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectTuner;
        kHIDUsage_Csmr_Quit: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Quit;
        kHIDUsage_Csmr_Help: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Help;
        kHIDUsage_Csmr_MediaSelectTape: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectTape;
        kHIDUsage_Csmr_MediaSelectCable: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectCable;
        kHIDUsage_Csmr_MediaSelectSatellite: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectSatellite;
        kHIDUsage_Csmr_MediaSelectSecurity: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectSecurity;
        kHIDUsage_Csmr_MediaSelectHome: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectHome;
        kHIDUsage_Csmr_MediaSelectCall: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MediaSelectCall;
        kHIDUsage_Csmr_ChannelIncrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelIncrement;
        kHIDUsage_Csmr_ChannelDecrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelDecrement;
        kHIDUsage_Csmr_Media: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Media;
        kHIDUsage_Csmr_VCRPlus: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_VCRPlus;
        kHIDUsage_Csmr_Once: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Once;
        kHIDUsage_Csmr_Daily: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Daily;
        kHIDUsage_Csmr_Weekly: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Weekly;
        kHIDUsage_Csmr_Monthly: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Monthly;
        kHIDUsage_Csmr_Play: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Play;
        kHIDUsage_Csmr_Pause: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Pause;
        kHIDUsage_Csmr_Record: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Record;
        kHIDUsage_Csmr_FastForward: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_FastForward;
        kHIDUsage_Csmr_Rewind: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Rewind;
        kHIDUsage_Csmr_ScanNextTrack: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ScanNextTrack;
        kHIDUsage_Csmr_ScanPreviousTrack: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ScanPreviousTrack;
        kHIDUsage_Csmr_Stop: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Stop;
        kHIDUsage_Csmr_Eject: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Eject;
        kHIDUsage_Csmr_RandomPlay: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_RandomPlay;
        kHIDUsage_Csmr_SelectDisc: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SelectDisc;
        kHIDUsage_Csmr_EnterDisc: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_EnterDisc;
        kHIDUsage_Csmr_Repeat: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Repeat;
        kHIDUsage_Csmr_Tracking: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Tracking;
        kHIDUsage_Csmr_TrackNormal: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_TrackNormal;
        kHIDUsage_Csmr_SlowTracking: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SlowTracking;
        kHIDUsage_Csmr_FrameForward: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_FrameForward;
        kHIDUsage_Csmr_FrameBack: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_FrameBack;
        kHIDUsage_Csmr_Mark: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Mark;
        kHIDUsage_Csmr_ClearMark: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ClearMark;
        kHIDUsage_Csmr_RepeatFromMark: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_RepeatFromMark;
        kHIDUsage_Csmr_ReturnToMark: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ReturnToMark;
        kHIDUsage_Csmr_SearchMarkForward: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SearchMarkForward;
        kHIDUsage_Csmr_SearchMarkBackwards: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SearchMarkBackwards;
        kHIDUsage_Csmr_CounterReset: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_CounterReset;
        kHIDUsage_Csmr_ShowCounter: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ShowCounter;
        kHIDUsage_Csmr_TrackingIncrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_TrackingIncrement;
        kHIDUsage_Csmr_TrackingDecrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_TrackingDecrement;
        kHIDUsage_Csmr_StopOrEject: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_StopOrEject;
        kHIDUsage_Csmr_PlayOrPause: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_PlayOrPause;
        kHIDUsage_Csmr_PlayOrSkip: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_PlayOrSkip;
        kHIDUsage_Csmr_Volume: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Volume;
        kHIDUsage_Csmr_Balance: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Balance;
        kHIDUsage_Csmr_Mute: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Mute;
        kHIDUsage_Csmr_Bass: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Bass;
        kHIDUsage_Csmr_Treble: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Treble;
        kHIDUsage_Csmr_BassBoost: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_BassBoost;
        kHIDUsage_Csmr_SurroundMode: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SurroundMode;
        kHIDUsage_Csmr_Loudness: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Loudness;
        kHIDUsage_Csmr_MPX: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_MPX;
        kHIDUsage_Csmr_VolumeIncrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_VolumeIncrement;
        kHIDUsage_Csmr_VolumeDecrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_VolumeDecrement;
        kHIDUsage_Csmr_Speed: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Speed;
        kHIDUsage_Csmr_PlaybackSpeed: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_PlaybackSpeed;
        kHIDUsage_Csmr_StandardPlay: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_StandardPlay;
        kHIDUsage_Csmr_LongPlay: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_LongPlay;
        kHIDUsage_Csmr_ExtendedPlay: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ExtendedPlay;
        kHIDUsage_Csmr_Slow: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Slow;
        kHIDUsage_Csmr_FanEnable: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_FanEnable;
        kHIDUsage_Csmr_FanSpeed: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_FanSpeed;
        kHIDUsage_Csmr_LightEnable: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_LightEnable;
        kHIDUsage_Csmr_LightIlluminationLevel: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_LightIlluminationLevel;
        kHIDUsage_Csmr_ClimateControlEnable: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ClimateControlEnable;
        kHIDUsage_Csmr_RoomTemperature: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_RoomTemperature;
        kHIDUsage_Csmr_SecurityEnable: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SecurityEnable;
        kHIDUsage_Csmr_FireAlarm: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_FireAlarm;
        kHIDUsage_Csmr_PoliceAlarm: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_PoliceAlarm;
        kHIDUsage_Csmr_BalanceRight: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_BalanceRight;
        kHIDUsage_Csmr_BalanceLeft: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_BalanceLeft;
        kHIDUsage_Csmr_BassIncrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_BassIncrement;
        kHIDUsage_Csmr_BassDecrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_BassDecrement;
        kHIDUsage_Csmr_TrebleIncrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_TrebleIncrement;
        kHIDUsage_Csmr_TrebleDecrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_TrebleDecrement;
        kHIDUsage_Csmr_SpeakerSystem: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SpeakerSystem;
        kHIDUsage_Csmr_ChannelLeft: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelLeft;
        kHIDUsage_Csmr_ChannelRight: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelRight;
        kHIDUsage_Csmr_ChannelCenter: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelCenter;
        kHIDUsage_Csmr_ChannelFront: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelFront;
        kHIDUsage_Csmr_ChannelCenterFront: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelCenterFront;
        kHIDUsage_Csmr_ChannelSide: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelSide;
        kHIDUsage_Csmr_ChannelSurround: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelSurround;
        kHIDUsage_Csmr_ChannelLowFrequencyEnhancement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelLowFrequencyEnhancement;
        kHIDUsage_Csmr_ChannelTop: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelTop;
        kHIDUsage_Csmr_ChannelUnknown: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ChannelUnknown;
        kHIDUsage_Csmr_SubChannel: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SubChannel;
        kHIDUsage_Csmr_SubChannelIncrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SubChannelIncrement;
        kHIDUsage_Csmr_SubChannelDecrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_SubChannelDecrement;
        kHIDUsage_Csmr_AlternateAudioIncrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_AlternateAudioIncrement;
        kHIDUsage_Csmr_AlternateAudioDecrement: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_AlternateAudioDecrement;
        kHIDUsage_Csmr_ApplicationLaunchButtons: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ApplicationLaunchButtons;
        kHIDUsage_Csmr_ALLaunchButtonConfigurationTool: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALLaunchButtonConfigurationTool;
        kHIDUsage_Csmr_ALProgrammableButtonConfiguration: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALProgrammableButtonConfiguration;
        kHIDUsage_Csmr_ALConsumerControlConfiguration: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALConsumerControlConfiguration;
        kHIDUsage_Csmr_ALWordProcessor: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALWordProcessor;
        kHIDUsage_Csmr_ALTextEditor: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALTextEditor;
        kHIDUsage_Csmr_ALSpreadsheet: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALSpreadsheet;
        kHIDUsage_Csmr_ALGraphicsEditor: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALGraphicsEditor;
        kHIDUsage_Csmr_ALPresentationApp: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALPresentationApp;
        kHIDUsage_Csmr_ALDatabaseApp: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALDatabaseApp;
        kHIDUsage_Csmr_ALEmailReader: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALEmailReader;
        kHIDUsage_Csmr_ALNewsreader: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALNewsreader;
        kHIDUsage_Csmr_ALVoicemail: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALVoicemail;
        kHIDUsage_Csmr_ALContactsOrAddressBook: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALContactsOrAddressBook;
        kHIDUsage_Csmr_ALCalendarOrSchedule: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALCalendarOrSchedule;
        kHIDUsage_Csmr_ALTaskOrProjectManager: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALTaskOrProjectManager;
        kHIDUsage_Csmr_ALLogOrJournalOrTimecard: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALLogOrJournalOrTimecard;
        kHIDUsage_Csmr_ALCheckbookOrFinance: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALCheckbookOrFinance;
        kHIDUsage_Csmr_ALCalculator: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALCalculator;
        kHIDUsage_Csmr_ALAOrVCaptureOrPlayback: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALAOrVCaptureOrPlayback;
        kHIDUsage_Csmr_ALLocalMachineBrowser: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALLocalMachineBrowser;
        kHIDUsage_Csmr_ALLANOrWANBrowser: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALLANOrWANBrowser;
        kHIDUsage_Csmr_ALInternetBrowser: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALInternetBrowser;
        kHIDUsage_Csmr_ALRemoteNetworkingOrISPConnect: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALRemoteNetworkingOrISPConnect;
        kHIDUsage_Csmr_ALNetworkConference: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALNetworkConference;
        kHIDUsage_Csmr_ALNetworkChat: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALNetworkChat;
        kHIDUsage_Csmr_ALTelephonyOrDialer: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALTelephonyOrDialer;
        kHIDUsage_Csmr_ALLogon: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALLogon;
        kHIDUsage_Csmr_ALLogoff: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALLogoff;
        kHIDUsage_Csmr_ALLogonOrLogoff: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALLogonOrLogoff;
        kHIDUsage_Csmr_ALTerminalLockOrScreensaver: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALTerminalLockOrScreensaver;
        kHIDUsage_Csmr_ALControlPanel: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALControlPanel;
        kHIDUsage_Csmr_ALCommandLineProcessorOrRun: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALCommandLineProcessorOrRun;
        kHIDUsage_Csmr_ALProcessOrTaskManager: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALProcessOrTaskManager;
        kHIDUsage_Csmr_AL: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_AL;
        kHIDUsage_Csmr_ALNextTaskOrApplication: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALNextTaskOrApplication;
        kHIDUsage_Csmr_ALPreviousTaskOrApplication: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALPreviousTaskOrApplication;
        kHIDUsage_Csmr_ALPreemptiveHaltTaskOrApplication: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALPreemptiveHaltTaskOrApplication;
        kHIDUsage_Csmr_ALIntegratedHelpCenter: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALIntegratedHelpCenter;
        kHIDUsage_Csmr_ALDocuments: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALDocuments;
        kHIDUsage_Csmr_ALThesaurus: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALThesaurus;
        kHIDUsage_Csmr_ALDictionary: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALDictionary;
        kHIDUsage_Csmr_ALDesktop: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALDesktop;
        kHIDUsage_Csmr_ALSpellCheck: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALSpellCheck;
        kHIDUsage_Csmr_ALGrammerCheck: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALGrammerCheck;
        kHIDUsage_Csmr_ALWirelessStatus: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALWirelessStatus;
        kHIDUsage_Csmr_ALKeyboardLayout: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALKeyboardLayout;
        kHIDUsage_Csmr_ALVirusProtection: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALVirusProtection;
        kHIDUsage_Csmr_ALEncryption: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALEncryption;
        kHIDUsage_Csmr_ALScreenSaver: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALScreenSaver;
        kHIDUsage_Csmr_ALAlarms: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALAlarms;
        kHIDUsage_Csmr_ALClock: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALClock;
        kHIDUsage_Csmr_ALFileBrowser: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALFileBrowser;
        kHIDUsage_Csmr_ALPowerStatus: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ALPowerStatus;
        kHIDUsage_Csmr_GenericGUIApplicationControls: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_GenericGUIApplicationControls;
        kHIDUsage_Csmr_ACNew: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACNew;
        kHIDUsage_Csmr_ACOpen: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACOpen;
        kHIDUsage_Csmr_ACClose: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACClose;
        kHIDUsage_Csmr_ACExit: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACExit;
        kHIDUsage_Csmr_ACMaximize: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACMaximize;
        kHIDUsage_Csmr_ACMinimize: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACMinimize;
        kHIDUsage_Csmr_ACSave: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACSave;
        kHIDUsage_Csmr_ACPrint: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACPrint;
        kHIDUsage_Csmr_ACProperties: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACProperties;
        kHIDUsage_Csmr_ACUndo: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACUndo;
        kHIDUsage_Csmr_ACCopy: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACCopy;
        kHIDUsage_Csmr_ACCut: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACCut;
        kHIDUsage_Csmr_ACPaste: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACPaste;
        kHIDUsage_Csmr_AC: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_AC;
        kHIDUsage_Csmr_ACFind: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACFind;
        kHIDUsage_Csmr_ACFindandReplace: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACFindandReplace;
        kHIDUsage_Csmr_ACSearch: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACSearch;
        kHIDUsage_Csmr_ACGoTo: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACGoTo;
        kHIDUsage_Csmr_ACHome: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACHome;
        kHIDUsage_Csmr_ACBack: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACBack;
        kHIDUsage_Csmr_ACForward: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACForward;
        kHIDUsage_Csmr_ACStop: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACStop;
        kHIDUsage_Csmr_ACRefresh: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACRefresh;
        kHIDUsage_Csmr_ACPreviousLink: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACPreviousLink;
        kHIDUsage_Csmr_ACNextLink: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACNextLink;
        kHIDUsage_Csmr_ACBookmarks: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACBookmarks;
        kHIDUsage_Csmr_ACHistory: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACHistory;
        kHIDUsage_Csmr_ACSubscriptions: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACSubscriptions;
        kHIDUsage_Csmr_ACZoomIn: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACZoomIn;
        kHIDUsage_Csmr_ACZoomOut: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACZoomOut;
        kHIDUsage_Csmr_ACZoom: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACZoom;
        kHIDUsage_Csmr_ACFullScreenView: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACFullScreenView;
        kHIDUsage_Csmr_ACNormalView: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACNormalView;
        kHIDUsage_Csmr_ACViewToggle: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACViewToggle;
        kHIDUsage_Csmr_ACScrollUp: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACScrollUp;
        kHIDUsage_Csmr_ACScrollDown: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACScrollDown;
        kHIDUsage_Csmr_ACScroll: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACScroll;
        kHIDUsage_Csmr_ACPanLeft: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACPanLeft;
        kHIDUsage_Csmr_ACPanRight: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACPanRight;
        kHIDUsage_Csmr_ACPan: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACPan;
        kHIDUsage_Csmr_ACNewWindow: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACNewWindow;
        kHIDUsage_Csmr_ACTileHorizontally: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACTileHorizontally;
        kHIDUsage_Csmr_ACTileVertically: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACTileVertically;
        kHIDUsage_Csmr_ACFormat: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_ACFormat;
        kHIDUsage_Csmr_Reserved: import("./hid-event").HIDUsageConsumerEvent.kHIDUsage_Csmr_Reserved;
        kHIDUsage_Tfon_Phone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Phone;
        kHIDUsage_Tfon_AnsweringMachine: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_AnsweringMachine;
        kHIDUsage_Tfon_MessageControls: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_MessageControls;
        kHIDUsage_Tfon_Handset: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Handset;
        kHIDUsage_Tfon_Headset: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Headset;
        kHIDUsage_Tfon_TelephonyKeyPad: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_TelephonyKeyPad;
        kHIDUsage_Tfon_ProgrammableButton: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_ProgrammableButton;
        kHIDUsage_Tfon_HookSwitch: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_HookSwitch;
        kHIDUsage_Tfon_Flash: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Flash;
        kHIDUsage_Tfon_Feature: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Feature;
        kHIDUsage_Tfon_Hold: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Hold;
        kHIDUsage_Tfon_Redial: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Redial;
        kHIDUsage_Tfon_Transfer: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Transfer;
        kHIDUsage_Tfon_Drop: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Drop;
        kHIDUsage_Tfon_Park: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Park;
        kHIDUsage_Tfon_ForwardCalls: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_ForwardCalls;
        kHIDUsage_Tfon_AlternateFunction: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_AlternateFunction;
        kHIDUsage_Tfon_Line: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Line;
        kHIDUsage_Tfon_SpeakerPhone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_SpeakerPhone;
        kHIDUsage_Tfon_Conference: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Conference;
        kHIDUsage_Tfon_RingEnable: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_RingEnable;
        kHIDUsage_Tfon_Ring: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Ring;
        kHIDUsage_Tfon_PhoneMute: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneMute;
        kHIDUsage_Tfon_CallerID: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_CallerID;
        kHIDUsage_Tfon_SpeedDial: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_SpeedDial;
        kHIDUsage_Tfon_StoreNumber: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_StoreNumber;
        kHIDUsage_Tfon_RecallNumber: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_RecallNumber;
        kHIDUsage_Tfon_PhoneDirectory: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneDirectory;
        kHIDUsage_Tfon_VoiceMail: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_VoiceMail;
        kHIDUsage_Tfon_ScreenCalls: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_ScreenCalls;
        kHIDUsage_Tfon_DoNotDisturb: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_DoNotDisturb;
        kHIDUsage_Tfon_Message: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_Message;
        kHIDUsage_Tfon_AnswerOnOrOff: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_AnswerOnOrOff;
        kHIDUsage_Tfon_InsideDialTone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_InsideDialTone;
        kHIDUsage_Tfon_OutsideDialTone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_OutsideDialTone;
        kHIDUsage_Tfon_InsideRingTone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_InsideRingTone;
        kHIDUsage_Tfon_OutsideRingTone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_OutsideRingTone;
        kHIDUsage_Tfon_PriorityRingTone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PriorityRingTone;
        kHIDUsage_Tfon_InsideRingback: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_InsideRingback;
        kHIDUsage_Tfon_PriorityRingback: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PriorityRingback;
        kHIDUsage_Tfon_LineBusyTone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_LineBusyTone;
        kHIDUsage_Tfon_ReorderTone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_ReorderTone;
        kHIDUsage_Tfon_CallWaitingTone: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_CallWaitingTone;
        kHIDUsage_Tfon_ConfirmationTone1: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_ConfirmationTone1;
        kHIDUsage_Tfon_ConfirmationTone2: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_ConfirmationTone2;
        kHIDUsage_Tfon_TonesOff: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_TonesOff;
        kHIDUsage_Tfon_OutsideRingback: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_OutsideRingback;
        kHIDUsage_Tfon_PhoneKey0: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey0;
        kHIDUsage_Tfon_PhoneKey1: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey1;
        kHIDUsage_Tfon_PhoneKey2: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey2;
        kHIDUsage_Tfon_PhoneKey3: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey3;
        kHIDUsage_Tfon_PhoneKey4: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey4;
        kHIDUsage_Tfon_PhoneKey5: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey5;
        kHIDUsage_Tfon_PhoneKey6: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey6;
        kHIDUsage_Tfon_PhoneKey7: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey7;
        kHIDUsage_Tfon_PhoneKey8: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey8;
        kHIDUsage_Tfon_PhoneKey9: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKey9;
        kHIDUsage_Tfon_PhoneKeyStar: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKeyStar;
        kHIDUsage_Tfon_PhoneKeyPound: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKeyPound;
        kHIDUsage_Tfon_PhoneKeyA: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKeyA;
        kHIDUsage_Tfon_PhoneKeyB: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKeyB;
        kHIDUsage_Tfon_PhoneKeyC: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKeyC;
        kHIDUsage_Tfon_PhoneKeyD: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_Tfon_PhoneKeyD;
        kHIDUsage_TFon_Reserved: import("./hid-event").HIDUsageTelephonyEvent.kHIDUsage_TFon_Reserved;
        kHIDUsage_PID_PhysicalInterfaceDevice: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_PhysicalInterfaceDevice;
        kHIDUsage_PID_Normal: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Normal;
        kHIDUsage_PID_SetEffectReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SetEffectReport;
        kHIDUsage_PID_EffectBlockIndex: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_EffectBlockIndex;
        kHIDUsage_PID_ParamBlockOffset: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ParamBlockOffset;
        kHIDUsage_PID_ROM_Flag: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ROM_Flag;
        kHIDUsage_PID_EffectType: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_EffectType;
        kHIDUsage_PID_ET_ConstantForce: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_ConstantForce;
        kHIDUsage_PID_ET_Ramp: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_Ramp;
        kHIDUsage_PID_ET_CustomForceData: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_CustomForceData;
        kHIDUsage_PID_ET_Square: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_Square;
        kHIDUsage_PID_ET_Sine: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_Sine;
        kHIDUsage_PID_ET_Triangle: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_Triangle;
        kHIDUsage_PID_ET_SawtoothUp: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_SawtoothUp;
        kHIDUsage_PID_ET_SawtoothDown: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_SawtoothDown;
        kHIDUsage_PID_ET_Spring: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_Spring;
        kHIDUsage_PID_ET_Damper: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_Damper;
        kHIDUsage_PID_ET_Inertia: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_Inertia;
        kHIDUsage_PID_ET_Friction: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ET_Friction;
        kHIDUsage_PID_Duration: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Duration;
        kHIDUsage_PID_SamplePeriod: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SamplePeriod;
        kHIDUsage_PID_Gain: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Gain;
        kHIDUsage_PID_TriggerButton: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_TriggerButton;
        kHIDUsage_PID_TriggerRepeatInterval: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_TriggerRepeatInterval;
        kHIDUsage_PID_AxesEnable: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_AxesEnable;
        kHIDUsage_PID_DirectionEnable: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DirectionEnable;
        kHIDUsage_PID_Direction: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Direction;
        kHIDUsage_PID_TypeSpecificBlockOffset: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_TypeSpecificBlockOffset;
        kHIDUsage_PID_BlockType: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_BlockType;
        kHIDUsage_PID_SetEnvelopeReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SetEnvelopeReport;
        kHIDUsage_PID_AttackLevel: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_AttackLevel;
        kHIDUsage_PID_AttackTime: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_AttackTime;
        kHIDUsage_PID_FadeLevel: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_FadeLevel;
        kHIDUsage_PID_FadeTime: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_FadeTime;
        kHIDUsage_PID_SetConditionReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SetConditionReport;
        kHIDUsage_PID_CP_Offset: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_CP_Offset;
        kHIDUsage_PID_PositiveCoefficient: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_PositiveCoefficient;
        kHIDUsage_PID_NegativeCoefficient: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_NegativeCoefficient;
        kHIDUsage_PID_PositiveSaturation: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_PositiveSaturation;
        kHIDUsage_PID_NegativeSaturation: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_NegativeSaturation;
        kHIDUsage_PID_DeadBand: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DeadBand;
        kHIDUsage_PID_DownloadForceSample: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DownloadForceSample;
        kHIDUsage_PID_IsochCustomForceEnable: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_IsochCustomForceEnable;
        kHIDUsage_PID_CustomForceDataReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_CustomForceDataReport;
        kHIDUsage_PID_CustomForceData: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_CustomForceData;
        kHIDUsage_PID_CustomForceVendorDefinedData: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_CustomForceVendorDefinedData;
        kHIDUsage_PID_SetCustomForceReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SetCustomForceReport;
        kHIDUsage_PID_CustomForceDataOffset: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_CustomForceDataOffset;
        kHIDUsage_PID_SampleCount: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SampleCount;
        kHIDUsage_PID_SetPeriodicReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SetPeriodicReport;
        kHIDUsage_PID_Offset: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Offset;
        kHIDUsage_PID_Magnitude: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Magnitude;
        kHIDUsage_PID_Phase: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Phase;
        kHIDUsage_PID_Period: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Period;
        kHIDUsage_PID_SetConstantForceReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SetConstantForceReport;
        kHIDUsage_PID_SetRampForceReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SetRampForceReport;
        kHIDUsage_PID_RampStart: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_RampStart;
        kHIDUsage_PID_RampEnd: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_RampEnd;
        kHIDUsage_PID_EffectOperationReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_EffectOperationReport;
        kHIDUsage_PID_EffectOperation: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_EffectOperation;
        kHIDUsage_PID_OpEffectStart: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_OpEffectStart;
        kHIDUsage_PID_OpEffectStartSolo: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_OpEffectStartSolo;
        kHIDUsage_PID_OpEffectStop: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_OpEffectStop;
        kHIDUsage_PID_LoopCount: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_LoopCount;
        kHIDUsage_PID_DeviceGainReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DeviceGainReport;
        kHIDUsage_PID_DeviceGain: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DeviceGain;
        kHIDUsage_PID_PoolReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_PoolReport;
        kHIDUsage_PID_RAM_PoolSize: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_RAM_PoolSize;
        kHIDUsage_PID_ROM_PoolSize: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ROM_PoolSize;
        kHIDUsage_PID_ROM_EffectBlockCount: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ROM_EffectBlockCount;
        kHIDUsage_PID_SimultaneousEffectsMax: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SimultaneousEffectsMax;
        kHIDUsage_PID_PoolAlignment: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_PoolAlignment;
        kHIDUsage_PID_PoolMoveReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_PoolMoveReport;
        kHIDUsage_PID_MoveSource: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_MoveSource;
        kHIDUsage_PID_MoveDestination: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_MoveDestination;
        kHIDUsage_PID_MoveLength: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_MoveLength;
        kHIDUsage_PID_BlockLoadReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_BlockLoadReport;
        kHIDUsage_PID_BlockLoadStatus: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_BlockLoadStatus;
        kHIDUsage_PID_BlockLoadSuccess: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_BlockLoadSuccess;
        kHIDUsage_PID_BlockLoadFull: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_BlockLoadFull;
        kHIDUsage_PID_BlockLoadError: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_BlockLoadError;
        kHIDUsage_PID_BlockHandle: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_BlockHandle;
        kHIDUsage_PID_BlockFreeReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_BlockFreeReport;
        kHIDUsage_PID_TypeSpecificBlockHandle: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_TypeSpecificBlockHandle;
        kHIDUsage_PID_StateReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_StateReport;
        kHIDUsage_PID_EffectPlaying: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_EffectPlaying;
        kHIDUsage_PID_DeviceControlReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DeviceControlReport;
        kHIDUsage_PID_DeviceControl: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DeviceControl;
        kHIDUsage_PID_DC_EnableActuators: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DC_EnableActuators;
        kHIDUsage_PID_DC_DisableActuators: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DC_DisableActuators;
        kHIDUsage_PID_DC_StopAllEffects: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DC_StopAllEffects;
        kHIDUsage_PID_DC_DeviceReset: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DC_DeviceReset;
        kHIDUsage_PID_DC_DevicePause: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DC_DevicePause;
        kHIDUsage_PID_DC_DeviceContinue: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DC_DeviceContinue;
        kHIDUsage_PID_DevicePaused: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DevicePaused;
        kHIDUsage_PID_ActuatorsEnabled: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ActuatorsEnabled;
        kHIDUsage_PID_SafetySwitch: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SafetySwitch;
        kHIDUsage_PID_ActuatorOverrideSwitch: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ActuatorOverrideSwitch;
        kHIDUsage_PID_ActuatorPower: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ActuatorPower;
        kHIDUsage_PID_StartDelay: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_StartDelay;
        kHIDUsage_PID_ParameterBlockSize: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_ParameterBlockSize;
        kHIDUsage_PID_DeviceManagedPool: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_DeviceManagedPool;
        kHIDUsage_PID_SharedParameterBlocks: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_SharedParameterBlocks;
        kHIDUsage_PID_CreateNewEffectReport: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_CreateNewEffectReport;
        kHIDUsage_PID_RAM_PoolAvailable: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_RAM_PoolAvailable;
        kHIDUsage_PID_Reserved: import("./hid-event").HIDUsagePIDEvent.kHIDUsage_PID_Reserved;
        kHIDUsage_MSR_Undefined: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_Undefined;
        kHIDUsage_MSR_DeviceReadOnly: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_DeviceReadOnly;
        kHIDUsage_MSR_Track1Length: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_Track1Length;
        kHIDUsage_MSR_Track2Length: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_Track2Length;
        kHIDUsage_MSR_Track3Length: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_Track3Length;
        kHIDUsage_MSR_TrackJISLength: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_TrackJISLength;
        kHIDUsage_MSR_TrackData: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_TrackData;
        kHIDUsage_MSR_Track1Data: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_Track1Data;
        kHIDUsage_MSR_Track2Data: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_Track2Data;
        kHIDUsage_MSR_Track3Data: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_Track3Data;
        kHIDUsage_MSR_TrackJISData: import("./hid-event").HIDUsageMSREvent.kHIDUsage_MSR_TrackJISData;
        kHIDUsage_PD_Undefined: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Undefined;
        kHIDUsage_PD_iName: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_iName;
        kHIDUsage_PD_PresentStatus: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_PresentStatus;
        kHIDUsage_PD_ChangedStatus: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ChangedStatus;
        kHIDUsage_PD_UPS: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_UPS;
        kHIDUsage_PD_PowerSupply: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_PowerSupply;
        kHIDUsage_PD_BatterySystem: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_BatterySystem;
        kHIDUsage_PD_BatterySystemID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_BatterySystemID;
        kHIDUsage_PD_Battery: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Battery;
        kHIDUsage_PD_BatteryID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_BatteryID;
        kHIDUsage_PD_Charger: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Charger;
        kHIDUsage_PD_ChargerID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ChargerID;
        kHIDUsage_PD_PowerConverter: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_PowerConverter;
        kHIDUsage_PD_PowerConverterID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_PowerConverterID;
        kHIDUsage_PD_OutletSystem: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_OutletSystem;
        kHIDUsage_PD_OutletSystemID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_OutletSystemID;
        kHIDUsage_PD_Input: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Input;
        kHIDUsage_PD_InputID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_InputID;
        kHIDUsage_PD_Output: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Output;
        kHIDUsage_PD_OutputID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_OutputID;
        kHIDUsage_PD_Flow: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Flow;
        kHIDUsage_PD_FlowID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_FlowID;
        kHIDUsage_PD_Outlet: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Outlet;
        kHIDUsage_PD_OutletID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_OutletID;
        kHIDUsage_PD_Gang: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Gang;
        kHIDUsage_PD_GangID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_GangID;
        kHIDUsage_PD_PowerSummary: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_PowerSummary;
        kHIDUsage_PD_PowerSummaryID: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_PowerSummaryID;
        kHIDUsage_PD_Voltage: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Voltage;
        kHIDUsage_PD_Current: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Current;
        kHIDUsage_PD_Frequency: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Frequency;
        kHIDUsage_PD_ApparentPower: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ApparentPower;
        kHIDUsage_PD_ActivePower: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ActivePower;
        kHIDUsage_PD_PercentLoad: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_PercentLoad;
        kHIDUsage_PD_Temperature: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Temperature;
        kHIDUsage_PD_Humidity: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Humidity;
        kHIDUsage_PD_BadCount: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_BadCount;
        kHIDUsage_PD_ConfigVoltage: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ConfigVoltage;
        kHIDUsage_PD_ConfigCurrent: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ConfigCurrent;
        kHIDUsage_PD_ConfigFrequency: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ConfigFrequency;
        kHIDUsage_PD_ConfigApparentPower: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ConfigApparentPower;
        kHIDUsage_PD_ConfigActivePower: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ConfigActivePower;
        kHIDUsage_PD_ConfigPercentLoad: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ConfigPercentLoad;
        kHIDUsage_PD_ConfigTemperature: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ConfigTemperature;
        kHIDUsage_PD_ConfigHumidity: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ConfigHumidity;
        kHIDUsage_PD_SwitchOnControl: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_SwitchOnControl;
        kHIDUsage_PD_SwitchOffControl: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_SwitchOffControl;
        kHIDUsage_PD_ToggleControl: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ToggleControl;
        kHIDUsage_PD_LowVoltageTransfer: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_LowVoltageTransfer;
        kHIDUsage_PD_HighVoltageTransfer: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_HighVoltageTransfer;
        kHIDUsage_PD_DelayBeforeReboot: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_DelayBeforeReboot;
        kHIDUsage_PD_DelayBeforeStartup: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_DelayBeforeStartup;
        kHIDUsage_PD_DelayBeforeShutdown: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_DelayBeforeShutdown;
        kHIDUsage_PD_Test: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Test;
        kHIDUsage_PD_ModuleReset: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ModuleReset;
        kHIDUsage_PD_AudibleAlarmControl: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_AudibleAlarmControl;
        kHIDUsage_PD_Present: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Present;
        kHIDUsage_PD_Good: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Good;
        kHIDUsage_PD_InternalFailure: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_InternalFailure;
        kHIDUsage_PD_VoltageOutOfRange: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_VoltageOutOfRange;
        kHIDUsage_PD_FrequencyOutOfRange: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_FrequencyOutOfRange;
        kHIDUsage_PD_Overload: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Overload;
        kHIDUsage_PD_OverCharged: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_OverCharged;
        kHIDUsage_PD_OverTemperature: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_OverTemperature;
        kHIDUsage_PD_ShutdownRequested: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ShutdownRequested;
        kHIDUsage_PD_ShutdownImminent: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_ShutdownImminent;
        kHIDUsage_PD_SwitchOnOff: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_SwitchOnOff;
        kHIDUsage_PD_Switchable: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Switchable;
        kHIDUsage_PD_Used: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Used;
        kHIDUsage_PD_Boost: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Boost;
        kHIDUsage_PD_Buck: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Buck;
        kHIDUsage_PD_Initialized: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Initialized;
        kHIDUsage_PD_Tested: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_Tested;
        kHIDUsage_PD_AwaitingPower: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_AwaitingPower;
        kHIDUsage_PD_CommunicationLost: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_CommunicationLost;
        kHIDUsage_PD_iManufacturer: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_iManufacturer;
        kHIDUsage_PD_iProduct: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_iProduct;
        kHIDUsage_PD_iserialNumber: import("./hid-event").HIDUsagePowerDeviceEvent.kHIDUsage_PD_iserialNumber;
        kHIDUsage_Ord_Instance1: import("./hid-event").HIDUsageOrdinalEvent.kHIDUsage_Ord_Instance1;
        kHIDUsage_Ord_Instance2: import("./hid-event").HIDUsageOrdinalEvent.kHIDUsage_Ord_Instance2;
        kHIDUsage_Ord_Instance3: import("./hid-event").HIDUsageOrdinalEvent.kHIDUsage_Ord_Instance3;
        kHIDUsage_Ord_Instance4: import("./hid-event").HIDUsageOrdinalEvent.kHIDUsage_Ord_Instance4;
        kHIDUsage_Ord_Instance65535: import("./hid-event").HIDUsageOrdinalEvent.kHIDUsage_Ord_Instance65535;
        kHIDUsage_Game_3DGameController: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_3DGameController;
        kHIDUsage_Game_PinballDevice: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_PinballDevice;
        kHIDUsage_Game_GunDevice: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GunDevice;
        kHIDUsage_Game_PointofView: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_PointofView;
        kHIDUsage_Game_TurnRightOrLeft: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_TurnRightOrLeft;
        kHIDUsage_Game_PitchUpOrDown: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_PitchUpOrDown;
        kHIDUsage_Game_RollRightOrLeft: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_RollRightOrLeft;
        kHIDUsage_Game_MoveRightOrLeft: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_MoveRightOrLeft;
        kHIDUsage_Game_MoveForwardOrBackward: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_MoveForwardOrBackward;
        kHIDUsage_Game_MoveUpOrDown: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_MoveUpOrDown;
        kHIDUsage_Game_LeanRightOrLeft: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_LeanRightOrLeft;
        kHIDUsage_Game_LeanForwardOrBackward: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_LeanForwardOrBackward;
        kHIDUsage_Game_HeightOfPOV: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_HeightOfPOV;
        kHIDUsage_Game_Flipper: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_Flipper;
        kHIDUsage_Game_SecondaryFlipper: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_SecondaryFlipper;
        kHIDUsage_Game_Bump: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_Bump;
        kHIDUsage_Game_NewGame: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_NewGame;
        kHIDUsage_Game_ShootBall: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_ShootBall;
        kHIDUsage_Game_Player: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_Player;
        kHIDUsage_Game_GunBolt: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GunBolt;
        kHIDUsage_Game_GunClip: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GunClip;
        kHIDUsage_Game_Gun: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_Gun;
        kHIDUsage_Game_GunSingleShot: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GunSingleShot;
        kHIDUsage_Game_GunBurst: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GunBurst;
        kHIDUsage_Game_GunAutomatic: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GunAutomatic;
        kHIDUsage_Game_GunSafety: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GunSafety;
        kHIDUsage_Game_GamepadFireOrJump: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GamepadFireOrJump;
        kHIDUsage_Game_GamepadTrigger: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_GamepadTrigger;
        kHIDUsage_Game_Reserved: import("./hid-event").HIDUsageGameEvent.kHIDUsage_Game_Reserved;
        kHIDUsage_AD_AlphanumericDisplay: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_AlphanumericDisplay;
        kHIDUsage_AD_DisplayAttributesReport: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_DisplayAttributesReport;
        kHIDUsage_AD_ASCIICharacterSet: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_ASCIICharacterSet;
        kHIDUsage_AD_DataReadBack: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_DataReadBack;
        kHIDUsage_AD_FontReadBack: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_FontReadBack;
        kHIDUsage_AD_DisplayControlReport: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_DisplayControlReport;
        kHIDUsage_AD_ClearDisplay: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_ClearDisplay;
        kHIDUsage_AD_DisplayEnable: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_DisplayEnable;
        kHIDUsage_AD_ScreenSaverDelay: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_ScreenSaverDelay;
        kHIDUsage_AD_ScreenSaverEnable: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_ScreenSaverEnable;
        kHIDUsage_AD_VerticalScroll: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_VerticalScroll;
        kHIDUsage_AD_HorizontalScroll: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_HorizontalScroll;
        kHIDUsage_AD_CharacterReport: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CharacterReport;
        kHIDUsage_AD_DisplayData: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_DisplayData;
        kHIDUsage_AD_DisplayStatus: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_DisplayStatus;
        kHIDUsage_AD_StatNotReady: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_StatNotReady;
        kHIDUsage_AD_StatReady: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_StatReady;
        kHIDUsage_AD_ErrNotaloadablecharacter: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_ErrNotaloadablecharacter;
        kHIDUsage_AD_ErrFontdatacannotberead: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_ErrFontdatacannotberead;
        kHIDUsage_AD_CursorPositionReport: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CursorPositionReport;
        kHIDUsage_AD_Row: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_Row;
        kHIDUsage_AD_Column: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_Column;
        kHIDUsage_AD_Rows: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_Rows;
        kHIDUsage_AD_Columns: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_Columns;
        kHIDUsage_AD_CursorPixelPositioning: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CursorPixelPositioning;
        kHIDUsage_AD_CursorMode: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CursorMode;
        kHIDUsage_AD_CursorEnable: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CursorEnable;
        kHIDUsage_AD_CursorBlink: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CursorBlink;
        kHIDUsage_AD_FontReport: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_FontReport;
        kHIDUsage_AD_FontData: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_FontData;
        kHIDUsage_AD_CharacterWidth: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CharacterWidth;
        kHIDUsage_AD_CharacterHeight: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CharacterHeight;
        kHIDUsage_AD_CharacterSpacingHorizontal: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CharacterSpacingHorizontal;
        kHIDUsage_AD_CharacterSpacingVertical: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_CharacterSpacingVertical;
        kHIDUsage_AD_UnicodeCharacterSet: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_UnicodeCharacterSet;
        kHIDUsage_AD_Reserved: import("./hid-event").HIDUsageAlphanumericDisplayEvent.kHIDUsage_AD_Reserved;
        kHIDUsage_Undefined: import("./hid-event").HIDUsageUndefinedEvent.kHIDUsage_Undefined;
        kHIDUsage_BS_Undefined: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_Undefined;
        kHIDUsage_BS_SMBBatteryMode: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBBatteryMode;
        kHIDUsage_BS_SMBBatteryStatus: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBBatteryStatus;
        kHIDUsage_BS_SMBAlarmWarning: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBAlarmWarning;
        kHIDUsage_BS_SMBChargerMode: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBChargerMode;
        kHIDUsage_BS_SMBChargerStatus: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBChargerStatus;
        kHIDUsage_BS_SMBChargerSpecInfo: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBChargerSpecInfo;
        kHIDUsage_BS_SMBSelectorState: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBSelectorState;
        kHIDUsage_BS_SMBSelectorPresets: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBSelectorPresets;
        kHIDUsage_BS_SMBSelectorInfo: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBSelectorInfo;
        kHIDUsage_BS_OptionalMfgFunction1: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_OptionalMfgFunction1;
        kHIDUsage_BS_OptionalMfgFunction2: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_OptionalMfgFunction2;
        kHIDUsage_BS_OptionalMfgFunction3: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_OptionalMfgFunction3;
        kHIDUsage_BS_OptionalMfgFunction4: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_OptionalMfgFunction4;
        kHIDUsage_BS_OptionalMfgFunction5: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_OptionalMfgFunction5;
        kHIDUsage_BS_ConnectionToSMBus: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ConnectionToSMBus;
        kHIDUsage_BS_OutputConnection: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_OutputConnection;
        kHIDUsage_BS_ChargerConnection: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ChargerConnection;
        kHIDUsage_BS_BatteryInsertion: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_BatteryInsertion;
        kHIDUsage_BS_Usenext: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_Usenext;
        kHIDUsage_BS_OKToUse: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_OKToUse;
        kHIDUsage_BS_BatterySupported: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_BatterySupported;
        kHIDUsage_BS_SelectorRevision: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SelectorRevision;
        kHIDUsage_BS_ChargingIndicator: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ChargingIndicator;
        kHIDUsage_BS_ManufacturerAccess: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ManufacturerAccess;
        kHIDUsage_BS_RemainingCapacityLimit: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_RemainingCapacityLimit;
        kHIDUsage_BS_RemainingTimeLimit: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_RemainingTimeLimit;
        kHIDUsage_BS_AtRate: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AtRate;
        kHIDUsage_BS_CapacityMode: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_CapacityMode;
        kHIDUsage_BS_BroadcastToCharger: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_BroadcastToCharger;
        kHIDUsage_BS_PrimaryBattery: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_PrimaryBattery;
        kHIDUsage_BS_ChargeController: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ChargeController;
        kHIDUsage_BS_TerminateCharge: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_TerminateCharge;
        kHIDUsage_BS_TerminateDischarge: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_TerminateDischarge;
        kHIDUsage_BS_BelowRemainingCapacityLimit: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_BelowRemainingCapacityLimit;
        kHIDUsage_BS_RemainingTimeLimitExpired: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_RemainingTimeLimitExpired;
        kHIDUsage_BS_Charging: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_Charging;
        kHIDUsage_BS_Discharging: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_Discharging;
        kHIDUsage_BS_FullyCharged: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_FullyCharged;
        kHIDUsage_BS_FullyDischarged: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_FullyDischarged;
        kHIDUsage_BS_ConditioningFlag: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ConditioningFlag;
        kHIDUsage_BS_AtRateOK: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AtRateOK;
        kHIDUsage_BS_SMBErrorCode: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SMBErrorCode;
        kHIDUsage_BS_NeedReplacement: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_NeedReplacement;
        kHIDUsage_BS_AtRateTimeToFull: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AtRateTimeToFull;
        kHIDUsage_BS_AtRateTimeToEmpty: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AtRateTimeToEmpty;
        kHIDUsage_BS_AverageCurrent: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AverageCurrent;
        kHIDUsage_BS_Maxerror: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_Maxerror;
        kHIDUsage_BS_RelativeStateOfCharge: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_RelativeStateOfCharge;
        kHIDUsage_BS_AbsoluteStateOfCharge: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AbsoluteStateOfCharge;
        kHIDUsage_BS_RemainingCapacity: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_RemainingCapacity;
        kHIDUsage_BS_FullChargeCapacity: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_FullChargeCapacity;
        kHIDUsage_BS_RunTimeToEmpty: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_RunTimeToEmpty;
        kHIDUsage_BS_AverageTimeToEmpty: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AverageTimeToEmpty;
        kHIDUsage_BS_AverageTimeToFull: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AverageTimeToFull;
        kHIDUsage_BS_CycleCount: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_CycleCount;
        kHIDUsage_BS_BattPackModelLevel: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_BattPackModelLevel;
        kHIDUsage_BS_InternalChargeController: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_InternalChargeController;
        kHIDUsage_BS_PrimaryBatterySupport: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_PrimaryBatterySupport;
        kHIDUsage_BS_DesignCapacity: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_DesignCapacity;
        kHIDUsage_BS_SpecificationInfo: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SpecificationInfo;
        kHIDUsage_BS_ManufacturerDate: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ManufacturerDate;
        kHIDUsage_BS_SerialNumber: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_SerialNumber;
        kHIDUsage_BS_iManufacturerName: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_iManufacturerName;
        kHIDUsage_BS_iDevicename: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_iDevicename;
        kHIDUsage_BS_iDeviceChemistry: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_iDeviceChemistry;
        kHIDUsage_BS_ManufacturerData: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ManufacturerData;
        kHIDUsage_BS_Rechargable: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_Rechargable;
        kHIDUsage_BS_WarningCapacityLimit: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_WarningCapacityLimit;
        kHIDUsage_BS_CapacityGranularity1: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_CapacityGranularity1;
        kHIDUsage_BS_CapacityGranularity2: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_CapacityGranularity2;
        kHIDUsage_BS_iOEMInformation: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_iOEMInformation;
        kHIDUsage_BS_InhibitCharge: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_InhibitCharge;
        kHIDUsage_BS_EnablePolling: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_EnablePolling;
        kHIDUsage_BS_ResetToZero: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ResetToZero;
        kHIDUsage_BS_ACPresent: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ACPresent;
        kHIDUsage_BS_BatteryPresent: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_BatteryPresent;
        kHIDUsage_BS_PowerFail: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_PowerFail;
        kHIDUsage_BS_AlarmInhibited: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_AlarmInhibited;
        kHIDUsage_BS_ThermistorUnderRange: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ThermistorUnderRange;
        kHIDUsage_BS_ThermistorHot: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ThermistorHot;
        kHIDUsage_BS_ThermistorCold: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ThermistorCold;
        kHIDUsage_BS_ThermistorOverRange: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ThermistorOverRange;
        kHIDUsage_BS_VoltageOutOfRange: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_VoltageOutOfRange;
        kHIDUsage_BS_CurrentOutOfRange: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_CurrentOutOfRange;
        kHIDUsage_BS_CurrentNotRegulated: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_CurrentNotRegulated;
        kHIDUsage_BS_VoltageNotRegulated: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_VoltageNotRegulated;
        kHIDUsage_BS_MasterMode: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_MasterMode;
        kHIDUsage_BS_ChargerSelectorSupport: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ChargerSelectorSupport;
        kHIDUsage_BS_ChargerSpec: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_ChargerSpec;
        kHIDUsage_BS_Level2: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_Level2;
        kHIDUsage_BS_Level3: import("./hid-event").HIDUsageBatterySystemEvent.kHIDUsage_BS_Level3;
    }, durationSeconds: string | number): Promise<unknown>;
}
export default _default;
import { HIDPageEvent } from './hid-event';
//# sourceMappingURL=iohid.d.ts.map